set samples 100000;
set isosamples 400;
set terminal epslatex  size 4.15,3.1125 color font ",8" standalone header "\\usepackage{amsmath}"
set output "phaseDiagram.tex";

set nokey;

set border 1+4+8 back;

set style line 1 lt 1 lc rgb "cyan" lw 2 pt 4 ps 2;
set style line 2 lt 2 lc rgb "red" lw 2 pt 2 ps 2;
set style line 3 lt 4 lc rgb "green" lw 2 pt 1 ps 2;
set style line 4 lt 4 lc rgb "red" lw 2 pt 1 ps 1;
set title;

set xrange [0:-3.5];
set yrange [0:24];

set xlabel '$t^\prime/t$';
set ylabel '$U/t$';

set ytics 0,2,20
set ytics add ('$\infty$' 24)

#U/t broken axis
set arrow 1 from 0,0 to 0,21.75 nohead back;
set arrow 2 from 0,22.25 to 0,24 nohead front;
set arrow 3 from 0.05,-3*0.05+21.75 to -0.05,3*0.05+21.75 nohead front;
set arrow 4 from 0.05,-3*0.05+22.25 to -0.05,3*0.05+22.25 nohead front;

set style arrow 1 heads size screen 0.004,90 ls 1 lw 3 lc rgb 'red';
set arrow from 0,3.7 to 0,3.9 as 1 front;
set arrow from -1,5.125 to -1,5.625 as 1 front;
set arrow from -2,7.5 to -2,8.0 as 1 front;
set arrow from -0.5,3.5 to -0.5,4.5 as 1 front;
set arrow from -1.5,5.5 to -1.5,6.5 as 1 front;


#t/U broken axis

f1(x)=a*exp(b*x)+c;
a=1;
b=0.1;
c=2.8;
fit f1(x) 'fitQMCWeakCoupling.txt' using 1:2 via a, b, c;

f2(x)=d*sqrt(x+e)+f;
d=11.547;
e=3.14083;
f=-4.33333;

f4(x)=a4/(-x-b4)**0.26+c4;
a4=6;
b4=1.4;
c4=-4;
fit f4(x) 'fit3.txt' using 1:2 via a4, b4, c4;

f6(x)=a6*exp(b6*x)+c6
a6=2e8;
b6=10;
c6=7;
fit f6(x) 'fitPCUT_critExpValues.txt' using 1:(1/($2)) via a6,b6,c6;

f7(x)=a7*sqrt(x-b7)
a7=7.143/0.94868;
b7=-3;


set label '\Large{SM}' at -1.4,2;
set label '\Large{AF}' at -0.4,9;
set label '\Large{VBS}' at -2.5,9;

set arrow from -1,0 to -1,24.0 nohead lc rgb 'black' lt 2 lw 2;
set arrow from -2,0 to -2,24.0 nohead lc rgb 'black' lt 2 lw 2;

plot 'critExpValues_o2o3o4o6_uptobandwidth.txt' using 1:(1/($2)) with points lc rgb 'blue' pt 7 ps 1.4 title '',\
'AFSpline.txt' using 1:2 smooth csplines with lines lt 1 lc rgb 'green' lw 3,\
'pCUTSplines.txt' using 1:(1/($2)) smooth csplines with lines lt 1 lc rgb 'blue' lw 3,\
'phaseDiagram.txt' using 1:2 with points lc rgb 'red' pt 7 ps 1.4 title '',\
'VBCtoSM.txt' using 1:2 with points lc rgb 'red' pt 7 ps 1.4 title '';


set output;
