import numpy as np
import matplotlib.pyplot as plt

myFontsize=8.0
myLinewidth=0.6
myMarkersize=2.5
dash_x=3
dash_y=2

plt.rc("text",usetex=True)
plt.rc("font",family="serif")
plt.rc("font",serif="Computer Modern Roman")
plt.rc("font",size=myFontsize)
plt.rc("axes",linewidth=myLinewidth)
figsize_x=4.15
figsize_y=3.1125

plt.figure(figsize=(figsize_x,figsize_y))

markerList=["o","s","d","^","v"]
colorList=["blue","green","red","cyan","magenta","orange","black"]


pCUT5_gCUT4=np.loadtxt("pCUT_s-2_onlyTo0_145.txt",unpack=True)
pCUT5_gCUT6=np.loadtxt("gapTargetValues_s-2_o2o3o4o6.txt",unpack=True)
pCUT6_gCUT4=np.loadtxt("gapTargetValues_o1to6_s-2_t0_01to0_13_dlogPade2_3.txt",unpack=True)
pCUT5_gCUT8=np.loadtxt("gapTargetValues_s-2_o2o3o4o6o8_abortAtMin.txt",unpack=True)
QMC=np.loadtxt("GapQMC.dat",unpack=True)

plt.plot(pCUT5_gCUT4[1],pCUT5_gCUT4[4]*pCUT5_gCUT4[6]/(16.0*pCUT5_gCUT4[1]**2),label=r"$\rm{pCUT}_5$ mit $\rm{gCUT}(4)$",color=colorList[0],linestyle="None",marker=markerList[0],markersize=myMarkersize,clip_on=False)
plt.plot(pCUT5_gCUT6[1],pCUT5_gCUT6[4]*pCUT5_gCUT6[6]/(16.0*pCUT5_gCUT6[1]**2),label=r"$\rm{pCUT}_5$ mit $\rm{gCUT}(6)$",color=colorList[1],linestyle="None",marker=markerList[0],markersize=myMarkersize,clip_on=False)
plt.plot(pCUT6_gCUT4[1],pCUT6_gCUT4[4]*pCUT6_gCUT4[6]/(16.0*pCUT6_gCUT4[1]**2),label=r"$\rm{pCUT}_6$ mit $\rm{gCUT}(4)$",color=colorList[2],linestyle="None",marker=markerList[0],markersize=myMarkersize,clip_on=False)
plt.plot(pCUT5_gCUT8[1],pCUT5_gCUT8[4]*pCUT5_gCUT8[6]/(16.0*pCUT5_gCUT8[1]**2),label=r"$\rm{pCUT}_5$ mit $\rm{gCUT}(8)$",color=colorList[3],linestyle="None",marker=markerList[0],markersize=myMarkersize,clip_on=False)
plt.plot(1.0/QMC[0],QMC[1]/QMC[0]*(QMC[0]**2)/16.0,label=r"QMC",color=colorList[4],linestyle="None",marker=markerList[1],markersize=myMarkersize,clip_on=False)
plt.errorbar([1.0/7.75], [0], xerr=[[0.0040323],[0.0043011]], fmt=markerList[1],color=colorList[4],markersize=myMarkersize,clip_on=False,zorder=10)


plt.axvline(1.0/7.75, color='k', linestyle='dashed',dashes=(dash_x,dash_y),linewidth=myLinewidth)

plt.xlim([0,0.145])
plt.xlabel("$t/U$")
plt.ylabel("$\Delta/(4{t^\prime}^2/U)$")

lgd1=plt.legend(loc="lower left",ncol=1, fontsize=myFontsize, fancybox=True)
lgd1.get_frame().set_linewidth(myLinewidth)

plt.savefig("gapCompare_tpm2_da.pdf")
plt.clf()

