import numpy as np
import matplotlib.pyplot as plt

myFontsize=8.0
myLinewidth=0.6
myMarkersize=2.5
dash_x=3
dash_y=2

plt.rc("text",usetex=True)
plt.rc("font",family="serif")
plt.rc("font",serif="Computer Modern Roman")
plt.rc("font",size=myFontsize)
plt.rc("axes",linewidth=myLinewidth)
figsize_x=4.15
figsize_y=3.1125*2.8
plt.figure(figsize=(figsize_x,figsize_y))

markerList=["o","s","d","^","v"]
colorList=["blue","green","red","cyan","magenta","orange","black"]

sList=[-1,-2,-3]
bandwithList=[1/(4*np.sqrt(2)),1/(2*np.sqrt(13)),1/(4*np.sqrt(5))]

left, bottom, width, height = [0.255, 0.565, 0.28, 0.095]
bottomList=[0.79,0.52,0.25]
sublabelList=["(a)","(b)","(c)"]

fig, axs = plt.subplots(3,sharex=False,sharey=False,figsize=(figsize_x,figsize_y))

insetList=[]
for sIndex in range(len(sList)):
	ax1=axs[sIndex]
	insetList.append(fig.add_axes([left, bottomList[sIndex], width, height]))
	ax2=insetList[sIndex]

	ax1.set_ylabel(r"$J_\alpha/J^\prime$")
	ax2.set_ylabel("$J^\prime/U$")
	ax2.set_xlabel("$t/U$")
	ax1.set_xlim([0,0.15])
	if(sIndex==0):
		ax2.set_xticks(np.arange(0.0,0.201,0.05))
		ax1.set_ylim([0,0.4])
		ax1.text(-0.025,0.4,sublabelList[sIndex],fontsize=10)	
		ax2.set_xlim([0,0.2])
		ax2.set_ylim([0,0.14])

	if(sIndex==1):
		ax2.set_xticks(np.arange(0.0,0.1501,0.05))
		ax1.set_ylim([0,0.70])
		ax1.text(-0.025,0.6,sublabelList[sIndex],fontsize=10)
		ax2.set_xlim([0.0,0.15])
		ax2.set_ylim([0.0,0.3])
	
	if(sIndex==2):
		ax1.set_xticks(np.arange(0,0.1501,0.025))
		ax2.set_xticks(np.arange(0.0,0.1501,0.05))
		ax1.set_ylim([0,0.4])
		ax1.set_xlabel("$t/U$")
		ax1.text(-0.025,0.4,sublabelList[sIndex],fontsize=10)	
		ax2.set_xlim([0.0,0.15])
		ax2.set_ylim([0.0,0.60])
	

	gCUT4=np.loadtxt("effSpinModel_s{0}_o2o3o4_abortAtMin.txt".format(sList[sIndex]),unpack=True)
	gCUT6=np.loadtxt("effSpinModel_s{0}_o2o3o4o6_abortAtMin.txt".format(sList[sIndex]),unpack=True)
	gCUT8=np.loadtxt("effSpinModel_s{0}_o2o3o4o6o8_abortAtMin.txt".format(sList[sIndex]),unpack=True)

	if(sIndex>0):
		#J1
		ax1.plot(gCUT4[0],gCUT4[1]/gCUT4[3],label="$J_1$",color=colorList[0],linestyle="None",marker=markerList[1],markersize=myMarkersize)
		ax1.plot(gCUT6[0],gCUT6[1]/gCUT6[3],color=colorList[0],linestyle="None",marker=markerList[2],markersize=myMarkersize)
		ax1.plot(gCUT8[0],gCUT8[1]/gCUT8[3],color=colorList[0],linestyle="None",marker=markerList[0],markersize=myMarkersize)
		#J2
		ax1.plot(gCUT4[0],gCUT4[2]/gCUT4[3],label="$J_2$",color=colorList[1],linestyle="None",marker=markerList[1],markersize=myMarkersize)
		ax1.plot(gCUT6[0],gCUT6[2]/gCUT6[3],color=colorList[1],linestyle="None",marker=markerList[2],markersize=myMarkersize)
		ax1.plot(gCUT8[0],gCUT8[2]/gCUT8[3],color=colorList[1],linestyle="None",marker=markerList[0],markersize=myMarkersize)

	#J3
	ax1.plot(gCUT4[0],gCUT4[4]/gCUT4[3],label=r"$J_3$",color=colorList[2],linestyle="None",marker=markerList[1],markersize=myMarkersize)
	ax1.plot(gCUT6[0],gCUT6[4]/gCUT6[3],color=colorList[2],linestyle="None",marker=markerList[2],markersize=myMarkersize)
	ax1.plot(gCUT8[0],gCUT8[4]/gCUT8[3],color=colorList[2],linestyle="None",marker=markerList[0],markersize=myMarkersize)
	#-Jpara
	ax1.plot(gCUT4[0],-gCUT4[5]/gCUT4[3],label="$-J_\parallel$",color=colorList[3],linestyle="None",marker=markerList[1],markersize=myMarkersize)
	ax1.plot(gCUT6[0],-gCUT6[5]/gCUT6[3],color=colorList[3],linestyle="None",marker=markerList[2],markersize=myMarkersize)
	ax1.plot(gCUT8[0],-gCUT8[5]/gCUT8[3],color=colorList[3],linestyle="None",marker=markerList[0],markersize=myMarkersize)
	#-J=
	ax1.plot(gCUT4[0],-gCUT4[6]/gCUT4[3],label="$-J_=$",color=colorList[4],linestyle="None",marker=markerList[1],markersize=myMarkersize)
	ax1.plot(gCUT6[0],-gCUT6[6]/gCUT6[3],color=colorList[4],linestyle="None",marker=markerList[2],markersize=myMarkersize)
	ax1.plot(gCUT8[0],-gCUT8[6]/gCUT8[3],color=colorList[4],linestyle="None",marker=markerList[0],markersize=myMarkersize)
	#-Jtimes
	ax1.plot(gCUT4[0],gCUT4[7]/gCUT4[3],label=r"$J_\times$",color=colorList[5],linestyle="None",marker=markerList[1],markersize=myMarkersize)
	ax1.plot(gCUT6[0],gCUT6[7]/gCUT6[3],color=colorList[5],linestyle="None",marker=markerList[2],markersize=myMarkersize)
	ax1.plot(gCUT8[0],gCUT8[7]/gCUT8[3],color=colorList[5],linestyle="None",marker=markerList[0],markersize=myMarkersize)

	ax1.axvline(bandwithList[sIndex], color='k', linestyle='dashed',dashes=(dash_x,dash_y),linewidth=myLinewidth)
	ax2.axvline(bandwithList[sIndex], color='k', linestyle='dashed',dashes=(dash_x,dash_y),linewidth=myLinewidth)

	#Jprime
	ax2.plot(gCUT4[0],gCUT4[3],color=colorList[0],label=r"$\rm{gCUT}(4)$",linestyle="solid",markersize=myMarkersize)
	ax2.plot(gCUT6[0],gCUT6[3],color=colorList[0],label=r"$\rm{gCUT}(6)$",linestyle="dashed",dashes=(dash_x,dash_y),markersize=myMarkersize)
	ax2.plot(gCUT8[0],gCUT8[3],color=colorList[0],label=r"$\rm{gCUT}(8)$",linestyle="None",marker=markerList[0],markersize=myMarkersize)
	
	if(sIndex==0 or sIndex==2):
		lgd1=ax1.legend(loc="upper right",bbox_to_anchor=(0.8,0.978),ncol=1, fontsize=myFontsize, fancybox=True)
		lgd1.get_frame().set_linewidth(myLinewidth)
	else:
		lgd1=ax1.legend(loc="upper right",bbox_to_anchor=(0.98,0.978),ncol=2, fontsize=myFontsize, fancybox=True)
		lgd1.get_frame().set_linewidth(myLinewidth)

	
	lgd2=ax2.legend(loc="upper left",fontsize=myFontsize-2, fancybox=True)
	lgd2.get_frame().set_linewidth(myLinewidth)


fig.subplots_adjust(hspace=0.06)
plt.setp([a.get_xticklabels() for a in fig.axes[:2]], visible=False)
plt.savefig("effCouplings_da.pdf".format(sList[sIndex]))
plt.clf()

