import matplotlib.pyplot as plt
import numpy as np

myFontsize=8.0
myLinewidth=0.6
myMarkersize=2.5
dash_x=3
dash_y=2

plt.rc("text",usetex=True)
params = {'text.latex.preamble' : [r"\usepackage{bm}"]}
plt.rcParams.update(params)
plt.rc("font",family="serif")
plt.rc("font",serif="Computer Modern Roman")
plt.rc("font",size=myFontsize)
plt.rc("axes",linewidth=myLinewidth)
figsize_x=6.5
figsize_y=7

myTextOffset1=-0.05
myTextOffset2=-0.022

f, ((ax11,ax12), (ax21, ax22), (ax31, ax32)) = plt.subplots(3, 2, sharex='col', sharey='row',figsize=(figsize_x,figsize_y))

markerList=["o","s","d","^","v"]
colorList=["blue","green","red","cyan","magenta","orange","black"]

dataList=[]

dataList.append([5,5,0,0,0,1])
dataList.append([5,5,0,0,0,-1])

J4List=[0.05,0.1,0.15,0.2,0.25]
axList=[ax11,ax21,ax22,ax31,ax32]

axIndex=0
for J4 in J4List:
	gseList=[]
	for data in dataList:
		gseTemp=np.loadtxt("eigenvalues_{0}x{1}/eigenvalues_J1J2J4_{0}x{1}_kx{2}ky{3}Sz{4}spinFlip{5}_J4{6}.txt".format(data[0],data[1],data[2],data[3],data[4],data[5],J4),unpack=True)
		gseList.append(gseTemp)


	gse=gseList[0][7]

	ax=axList[axIndex]

	for i in range(len(dataList)):
		size=(dataList[i][0]+1)*(dataList[i][1]+1)
		ax.plot(gseList[i][1],(gseList[i][7]-gse)/size,marker=markerList[0],color=colorList[2*i],markersize=myMarkersize,linestyle="None",label=r"$\bm{{k}}=({2},{3})$, $f={4}$, GZ".format(size,dataList[i][4],dataList[i][2],dataList[i][3],dataList[i][5]))
		ax.plot(gseList[i][1],(gseList[i][8]-gse)/size,marker=markerList[3],color=colorList[2*i],markersize=myMarkersize,linestyle="None",label=r"$\bm{{k}}=({2},{3})$, $f={4}$, $1.$ Anreg.".format(size,dataList[i][4],dataList[i][2],dataList[i][3],dataList[i][5]))
	
	axIndex=axIndex+1


ax12.axis("off")
ax12.plot([-1],[0.01],marker=markerList[0],color=colorList[0],markersize=myMarkersize,linestyle="None",label=r"$\bm{{k}}=(0,0)$, $f=1$, GZ")
ax12.plot([-1],[0.01],marker=markerList[3],color=colorList[0],markersize=myMarkersize,linestyle="None",label=r"$\bm{{k}}=(0,0)$, $f=1$, $1.$ Anreg.")
ax12.plot([-1],[0.01],marker=markerList[0],color=colorList[2],markersize=myMarkersize,linestyle="None",label=r"$\bm{{k}}=(0,0)$, $f=-1$, GZ")
ax12.plot([-1],[0.01],marker=markerList[3],color=colorList[2],markersize=myMarkersize,linestyle="None",label=r"$\bm{{k}}=(0,0)$, $f=-1$, $1.$ Anreg.")
lgd=ax12.legend(ncol=1,loc="center",fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)
ax31.set_xlabel("$J_2/J_1$")
ax32.set_xlabel("$J_2/J_1$")
ax11.set_ylabel("$(e_i-e_0)/J_1$")
ax21.set_ylabel("$(e_i-e_0)/J_1$")
ax31.set_ylabel("$(e_i-e_0)/J_1$")
plt.xlim([0,0.25])
ax11.set_ylim([0,0.08])
ax21.set_ylim([0,0.08])
ax31.set_ylim([0,0.08])

ax11.text(myTextOffset1,0.08,"(a)",fontsize=10)
ax11.text(0.015,0.07,"$J_4/J_1=0.05$",fontsize=myFontsize)

ax21.text(myTextOffset1,0.08,"(b)",fontsize=10)
ax21.text(0.015,0.072,"$J_4/J_1=0.1$",fontsize=myFontsize)

ax22.text(myTextOffset2,0.08,"(c)",fontsize=10)
ax22.text(0.015,0.072,"$J_4/J_1=0.15$",fontsize=myFontsize)

ax31.text(myTextOffset1,0.08,"(d)",fontsize=10)
ax31.text(0.015,0.072,"$J_4/J_1=0.2$",fontsize=myFontsize)

ax32.text(myTextOffset2,0.08,"(e)",fontsize=10)
ax32.text(0.015,0.072,"$J_4/J_1=0.25$",fontsize=myFontsize)

# Fine-tune figure; make subplots close to each other and hide x ticks for 
# all but bottom plot. 
f.subplots_adjust(hspace=0.08,wspace=0.14) 


plt.savefig("gse_PI_THM_J1J2J4_5x5_da.pdf".format(J4))
plt.clf()

