import matplotlib.pyplot as plt
import numpy as np

myFontsize=8.0
myLinewidth=0.6
myMarkersize=2.5
dash_x=3
dash_y=2

plt.rc("text",usetex=True)
params = {'text.latex.preamble' : [r"\usepackage{bm}"]}
plt.rcParams.update(params)
plt.rc("font",family="serif")
plt.rc("font",serif="Computer Modern Roman")
plt.rc("font",size=myFontsize)
plt.rc("axes",linewidth=myLinewidth)
myFigsize_x=4.15
myFigsize_y=3.1125*2.2
myTextOffset=-0.37/2*0.8

markerList=["o","s","d","^","v"]
markerList2=["^","s","d","o"]
colorList=["blue","green","red","cyan","magenta","orange","black"]


f, (ax1, ax2) = plt.subplots(2, sharex=False, sharey=False,figsize=(myFigsize_x, myFigsize_y)) #share x- and y-axis

dataList=[]

dataList.append([5,2,0,0,0,-1])
dataList.append([5,3,0,0,0,1])
dataList.append([5,4,0,0,0,-1])
dataList.append([5,5,0,0,0,1])

gseList=[]
for data in dataList:
	gseTemp=np.loadtxt("eigenvalues_J1J4_{0}x{1}/eigenvalues_J1J4_{0}x{1}_kx{2}ky{3}Sz{4}spinFlip{5}.txt".format(*data),unpack=True)
	gseList.append(gseTemp)

for i in range(len(dataList)):
	size=(dataList[i][0]+1)*(dataList[i][1]+1)
	ax1.plot(gseList[i][1],(gseList[i][6])/size,color=colorList[i],marker=markerList2[i],markersize=myMarkersize,linestyle="None",label=r"$N={0}$".format(size,dataList[i][4],dataList[i][2],dataList[i][3],dataList[i][5]))

ax1.set_xlabel("$J_4/J_1$")
ax1.set_ylabel("$e_0/J_1$")

ax1.set_xlim([0,0.8])
ax1.text(myTextOffset,-0.5,"(a)",fontsize=10)
lgd=ax1.legend(loc="upper right",ncol=1, fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)

tStep=0.01
hNumber=1
h=tStep*hNumber


#second derivative
for i in range(len(dataList)):
	size=(dataList[i][0]+1)*(dataList[i][1]+1)
	dde0=(gseList[i][6][8*hNumber:]-16*gseList[i][6][7*hNumber:-hNumber]+64*gseList[i][6][6*hNumber:-2*hNumber]+16*gseList[i][6][5*hNumber:-3*hNumber]-130*gseList[i][6][4*hNumber:-4*hNumber]+16*gseList[i][6][3*hNumber:-5*hNumber]+64*gseList[i][6][2*hNumber:-6*hNumber]-16*gseList[i][6][hNumber:-7*hNumber]+gseList[i][6][0:-8*hNumber])/(144*h**2)
	
	ax2.plot(gseList[i][1][4*hNumber:-4*hNumber],dde0/size,marker=markerList2[i],color=colorList[i],markersize=myMarkersize,linestyle="None",label=r"$N={0}$".format(size,dataList[i][4],dataList[i][2],dataList[i][3],dataList[i][5]))

ax2.set_xlim([0,0.8])
ax2.text(myTextOffset,0.0,"(b)",fontsize=10)
ax2.set_xlabel("$J_4/J_1$")
ax2.set_ylabel(r"$\mathrm{d}^2 e_0/\mathrm{d}J_4^2 \cdot J_1$")
lgd=ax2.legend(loc="lower right",ncol=1, fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)
plt.savefig("gse_ddgse_PI_THM_J1J4_allClusters_da.pdf")
plt.clf()

