import matplotlib.pyplot as plt
import numpy as np
from itertools import cycle

myFontsize=8.0
myLinewidth=0.6
myMarkersize=2.5
dash_x=3
dash_y=2

plt.rc("text",usetex=True)
params = {'text.latex.preamble' : [r"\usepackage{bm}"]}
plt.rcParams.update(params)
plt.rc("font",family="serif")
plt.rc("font",serif="Computer Modern Roman")
plt.rc("font",size=myFontsize)
plt.rc("axes",linewidth=myLinewidth)
myFigsize_x=4.15
myFigsize_y=3.1125
myTextOffset=-0.37/2*0.25

plt.figure(figsize=(myFigsize_x,myFigsize_y))

markerList=["o","s","d","^","v"]
colorList=["blue","green","red","cyan","magenta","orange","black"]

xyList=[[5,2,-1],[5,3,1],[5,4,-1],[5,5,1]]

q20=[]

for [x,y,spinFlip] in xyList:
	modValue=(x+1)*(y+1)
	ssf=np.loadtxt("spinStructureFactor_J1J4_{0}x{1}/spinStructureFactor_J1J4_{0}x{1}_kx0ky0Sz0spinFlip{2}.txt".format(x,y,spinFlip),unpack=True)

	whatever=[]
	q=[]
	for qx in range(x+1):
		for qy in range(y+1):
			q.append([qx,qy])
	for i in range(len(q)):
		whatever.append([])

	for i in range(len(ssf[0])):
		whatever[i%modValue].append([ssf[1][i],ssf[8][i]])

	for i in range(modValue):
		whatever[i]=np.array(whatever[i])

	whatever=np.array(whatever)
	for i in range(len(q)):
		if(q[i][0]==2 and q[i][1]==0):
			q20.append(whatever[i])

	# now find equivalent q
	zeroEPS=0.001
	qDistinct=[]
	for i in range(len(q)):
		qTemp=[]
		print("q=({0},{1})".format(q[i][0],q[i][1]))
		equiv=False
		for j in range(len(qDistinct)):
			tempWhatever=abs((whatever[i].T)[1]-(whatever[qDistinct[j][0]].T)[1])
			print(" q=({0},{1}) => {2}".format(q[qDistinct[j][0]][0],q[qDistinct[j][0]][1],max(tempWhatever)))
			if(max(tempWhatever)<zeroEPS):
				equiv=True
				qDistinct[j].append(i)
		if(equiv==False):
			qTemp.append(i)
			qDistinct.append(qTemp)

	markercycler=cycle(markerList)
	for i in range(len(qDistinct)):
		labelString=r"$\bm{{q}}=({0},{1})".format(q[qDistinct[i][0]][0],q[qDistinct[i][0]][1])
		for j in range(1,len(qDistinct[i])):
			labelString+=","
			if(j%4==0):
				labelString+="$\n$"
			labelString+="({0},{1})".format(q[qDistinct[i][j]][0],q[qDistinct[i][j]][1])

		labelString+="$"
		
		plt.plot((whatever[qDistinct[i][0]].T)[0],(whatever[qDistinct[i][0]].T)[1]*1.0/(4.0*(x+1)*(y+1)),next(markercycler),markersize=myMarkersize,label=labelString)

	plt.xlim([0.0,0.8])
	#plt.ylim([-0.001,0.01])
	plt.xlabel(r"$J_4/J_1$")
	plt.ylabel(r"$S^{{zz}}(\bm{q})$")
	anchor_x=1.6
	ancor_y=1.025
	#if(y==3):


	lgd=plt.legend(loc="upper left",bbox_to_anchor=(1.05, 1.025),ncol=1, fontsize=myFontsize,fancybox=True)
	lgd.get_frame().set_linewidth(myLinewidth)
	plt.savefig("ssf_PI_THM_J1J4_{0}x{1}.pdf".format(x,y,spinFlip))
	plt.clf()


# plot in one diagram
markerList2=["^","s","d","o"]
for i in range(len(xyList)):
	numberOfSites=(xyList[i][0]+1)*(xyList[i][1]+1)
	plt.plot((q20[i].T)[0],(q20[i].T)[1]*1.0/(4.0*numberOfSites**2),"o",color=colorList[i],marker=markerList2[i],markersize=myMarkersize,label="$N={0}$".format(numberOfSites))

plt.xlabel(r"$J_4/J_1$")
plt.ylabel(r"$S^{{zz}}(\bm{q})/N$")
plt.xlim([0.0,0.8])
lgd=plt.legend(loc="center right",ncol=1, fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)
plt.savefig("ssf_PI_THM_J1J4_q20.pdf")
plt.clf()

