import matplotlib.pyplot as plt
import numpy as np

myFontsize=8.0
myLinewidth=0.6
myMarkersize=2.5
dash_x=3
dash_y=2

plt.rc("text",usetex=True)
params = {'text.latex.preamble' : [r"\usepackage{bm}"]}
plt.rcParams.update(params)
plt.rc("font",family="serif")
plt.rc("font",serif="Computer Modern Roman")
plt.rc("font",size=myFontsize)
plt.rc("axes",linewidth=myLinewidth)
myTextOffset=-0.37
figsize_x=4.15
figsize_y=3.1125*2.2
plt.figure(figsize=(figsize_x,figsize_y))

markerList=["o","s","d","^","v"]
colorList=["blue","green","red","cyan","magenta","orange","black"]

f, (ax1, ax2) = plt.subplots(2, sharex=False, sharey=False,figsize=(figsize_x, figsize_y))

dataList=[]

dataList.append([5,5,0,0,0,1])
dataList.append([5,5,0,0,0,-1])

gseList=[]
for data in dataList:
	gseTemp=np.loadtxt("eigenvalues_{0}x{1}/eigenvalues_order4_6erSeries_{0}x{1}_kx{2}ky{3}Sz{4}spinFlip{5}.txt".format(*data),unpack=True)
	gseList.append(gseTemp)


gse=gseList[0][5]

for i in range(len(dataList)):
	size=(dataList[i][0]+1)*(dataList[i][1]+1)
	ax1.plot(gseList[i][0],(gseList[i][5]-gse)/size,marker=markerList[0],color=colorList[2*i],markersize=myMarkersize,linestyle="None",label=r"$\bm{{k}}=({2},{3})$, $f={4}$ GZ".format(size,dataList[i][4],dataList[i][2],dataList[i][3],dataList[i][5]))
	ax1.plot(gseList[i][0],(gseList[i][6]-gse)/size,marker=markerList[3],color=colorList[2*i],markersize=myMarkersize,linestyle="None",label=r"$\bm{{k}}=({2},{3})$, $f={4}$ $1.$ Anreg.".format(size,dataList[i][4],dataList[i][2],dataList[i][3],dataList[i][5]))

ax1.set_xlabel("$t/U$")
ax1.set_ylabel("$(e_i-e_0)/U$")

lgd=ax1.legend(ncol=1,loc="upper left",fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)

tStep=0.01
hNumber=1
h=tStep*hNumber


#second derivative
#for i in range(len(dataList)):
i=0
size=(dataList[i][0]+1)*(dataList[i][1]+1)
dde0=(gseList[i][5][8*hNumber:]-16*gseList[i][5][7*hNumber:-hNumber]+64*gseList[i][5][6*hNumber:-2*hNumber]+16*gseList[i][5][5*hNumber:-3*hNumber]-130*gseList[i][5][4*hNumber:-4*hNumber]+16*gseList[i][5][3*hNumber:-5*hNumber]+64*gseList[i][5][2*hNumber:-6*hNumber]-16*gseList[i][5][hNumber:-7*hNumber]+gseList[i][5][0:-8*hNumber])/(144*h**2)
	
ax2.plot(gseList[i][0][4*hNumber:-4*hNumber],dde0,marker="o",color="blue",markersize=myMarkersize,linestyle="None")

ax2.set_xlabel("$t/U$")
ax2.set_ylabel(r"$\mathrm{d}^2e_0/\mathrm{d}t^2 U$")
ax2.set_xlim([0,0.3])

ax1.text(myTextOffset/2*0.3,0.06,"(a)",fontsize=10)
ax2.text(myTextOffset/2*0.3,-400,"(b)",fontsize=10)

plt.savefig("gse_ddgse_PI_THM_order4_5x5_da.pdf")
plt.clf()
