import numpy as np
import matplotlib.pyplot as plt

#import locale
#locale.setlocale(locale.LC_ALL, "de_DE")
#plt.rcParams['axes.formatter.use_locale'] = True

#import matplotlib
#print(matplotlib.__version__)

dash_x=3
dash_y=2

myFontsize=8.0
myLinewidth=0.6
myMarkersize=2.5
myFigsize_x=4.15
myFigsize_y=3.1125*2.2
myTextOffset=-0.37
plt.rc("text",usetex=True)
plt.rc("font",family="serif")
plt.rc("font",serif="Computer Modern Roman")
plt.rc("font",size=myFontsize)
plt.rc("axes",linewidth=myLinewidth)
#plt.figure(figsize=(4.72441,3.54331))
#plt.figure(figsize=(myFigsize_x,myFigsize_y))


### GROUND-STATE ENERGY ###
markerList=["o","s","d","^","v"]
colorList=["blue","green","red","cyan","magenta","orange","black"]

fig, (ax1, ax2) = plt.subplots(2, sharex=False, sharey=False,figsize=(myFigsize_x, myFigsize_y)) #share x- and y-axis

### spin-gap ###
Delta_N3=np.loadtxt("fig5/Delta_N3.dat",unpack=True)
Delta_N4=np.loadtxt("fig5/Delta_N4.dat",unpack=True)
Delta_N5=np.loadtxt("fig5/Delta_N5.dat",unpack=True)
Delta_N6=np.loadtxt("fig5/Delta_N6.dat",unpack=True)
DeltaC_points=np.loadtxt("fig5/DeltaC_points.dat",unpack=True)
DeltaC_fit=np.loadtxt("fig5/DeltaC_fit.dat",unpack=True)
lambdaC_points=np.loadtxt("fig5/lambdaC_points.dat",unpack=True)
lambdaC_line=np.loadtxt("fig5/lambdaC_line.dat",unpack=True)

ax1.plot(Delta_N3[0],Delta_N3[1],label=r"$N_\mathrm{dr}=3$",color=colorList[0])
ax1.plot(Delta_N4[0],Delta_N4[1],label=r"$N_\mathrm{dr}=4$",color=colorList[1])
ax1.plot(Delta_N5[0],Delta_N5[1],label=r"$N_\mathrm{dr}=5$",color=colorList[2])
ax1.plot(Delta_N6[0],Delta_N6[1],label=r"$N_\mathrm{dr}=6$",color=colorList[3])

lgd=ax1.legend(loc="upper left",bbox_to_anchor=(0.265,1.0),ncol=1, fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)
ax1.set_ylim([0.0,1.0])
ax1.text(myTextOffset/2.0,1,"(a)",fontsize=10)
ax1.set_xlabel("$\lambda$")
ax1.set_ylabel("$\Delta/J$")

# inset DeltaC
left, bottom, width, height = [0.245, 0.595, 0.21, 0.11]
ax1_inset1 = fig.add_axes([left, bottom, width, height])
ax1_inset1.plot(DeltaC_points[0],DeltaC_points[1],marker="s",linestyle="none",markersize=myMarkersize,color="black")
ax1_inset1.plot(DeltaC_fit[0],DeltaC_fit[1],color="black")
ax1_inset1.set_xticks(np.arange(0,0.3001,0.1))
ax1_inset1.set_yticks(np.arange(0,0.4001,0.1))
ax1_inset1.set_xlabel(r"$1/N_\mathrm{dr}$")
ax1_inset1.set_ylabel(r"$\Delta_\mathrm{c}$")

ax1.axvline(0.802,0,0.21, color='k', linestyle='dashed',dashes=(dash_x,dash_y),linewidth=myLinewidth)

# inset lambdaC
left=0.655
bottom=0.775
ax1_inset2=fig.add_axes([left, bottom, width, height])
ax1_inset2.plot(lambdaC_points[0],lambdaC_points[1],marker="s",linestyle="none",markersize=myMarkersize,color="black")
ax1_inset2.plot(lambdaC_line[0],lambdaC_line[1],color="black")
ax1_inset2.set_xticks(np.arange(0,0.3001,0.1))
#ax1_inset2.set_yticks(np.arange(0.8,0.84001,0.02))
ax1_inset2.set_ylim([0.8,0.85])
ax1_inset2.set_xlabel(r"$1/N_\mathrm{dr}$")
ax1_inset2.set_ylabel(r"$\lambda_\mathrm{c}$")

### ddgse ###
ddepsilon0_N4=np.loadtxt("fig5/ddepsilon0_N4.dat",unpack=True)
ddepsilon0_N5=np.loadtxt("fig5/ddepsilon0_N5.dat",unpack=True)
ddepsilon0_N6=np.loadtxt("fig5/ddepsilon0_N6.dat",unpack=True)

ax2.plot(ddepsilon0_N4[0],ddepsilon0_N4[1],label=r"$N_\mathrm{dr}=4$",color=colorList[1])
ax2.plot(ddepsilon0_N5[0],ddepsilon0_N5[1],label=r"$N_\mathrm{dr}=5$",color=colorList[2])
ax2.plot(ddepsilon0_N6[0],ddepsilon0_N6[1],label=r"$N_\mathrm{dr}=6$",color=colorList[3])

lgd=ax2.legend(loc="lower right",ncol=1, fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)
ax2.set_xlabel(r"$\lambda$")
ax2.set_ylabel(r"$(\mathrm{d}^2e_0^{(N_\mathrm{dr})}/\mathrm{d}\lambda^2)/J$")
ax2.set_xlim([0.55,1])
ax2.text(myTextOffset/2.0*0.45+0.55,-4,"(b)",fontsize=10)
ax2.set_ylim([-11,-4])


plt.savefig("TriangleChain_periodic_spinGap.pdf")
plt.clf()

