import matplotlib.pyplot as plt
import numpy as np

myFontsize=8.0
myLinewidth=0.6
myMarkersize=2.5
myFigsize_x=4.15
myFigsize_y=3.1125
myTextOffset=-0.37
plt.rc("text",usetex=True)
plt.rc("font",family="serif")
plt.rc("font",serif="Computer Modern Roman")
plt.rc("font",size=myFontsize)
plt.rc("axes",linewidth=myLinewidth)

markerList=["o","s","d","^","v"]
colorList=["blue","green","red","cyan","magenta","orange","black"]

lambdaList=[0.1,0.3,0.5,0.7,0.8,0.82,0.9,1.0]
iPEPSList=[-1.006428851327403,-1.052873659249132,-1.132224326859052,-1.233002024151315,-1.2669,-1.30085855431342,-1.348663158111413,-1.411134604300319]
pList=np.zeros(len(lambdaList))

index=0
for lambdaValue in lambdaList:
	plt.figure()
	fig, ax1 = plt.subplots(figsize=(myFigsize_x,myFigsize_y))

	# These are in unitless percentages of the figure size. (0,0 is bottom left)
	left, bottom, width, height = [0.35, 0.23, 0.27, 0.185]
	ax2 = fig.add_axes([left, bottom, width, height])

	e0_order2=np.loadtxt("results_kagomeOne_fullExpansion_K_lambda{0}/e0_order2.txt".format(lambdaValue),unpack=True)
	e0_order3=np.loadtxt("results_kagomeOne_fullExpansion_K_lambda{0}/e0_order3.txt".format(lambdaValue),unpack=True)
	e0_order4=np.loadtxt("results_kagomeOne_fullExpansion_K_lambda{0}/e0_order4.txt".format(lambdaValue),unpack=True)
	e0_order5=np.loadtxt("results_kagomeOne_fullExpansion_K_lambda{0}/e0_order5.txt".format(lambdaValue),unpack=True)
	e0_order6=np.loadtxt("results_kagomeOne_fullExpansion_K_lambda{0}/e0_order6.txt".format(lambdaValue),unpack=True)

	ax1.plot(e0_order2[0],e0_order2[1]/3,label=r"$N_\mathrm{dr}=2$",marker="o",markersize=myMarkersize,linewidth=myLinewidth,color=colorList[0])
	ax1.plot(e0_order3[0],e0_order3[1]/3,label=r"$N_\mathrm{dr}=3$",marker="o",markersize=myMarkersize,linewidth=myLinewidth,color=colorList[1])
	ax1.plot(e0_order4[0],e0_order4[1]/3,label=r"$N_\mathrm{dr}=4$",marker="o",markersize=myMarkersize,linewidth=myLinewidth,color=colorList[2])
	ax1.plot(e0_order5[0],e0_order5[1]/3,label=r"$N_\mathrm{dr}=5$",marker="o",markersize=myMarkersize,linewidth=myLinewidth,color=colorList[3])
	ax1.plot(e0_order6[0],e0_order6[1]/3,label=r"$N_\mathrm{dr}=6$",marker="o",markersize=myMarkersize,linewidth=myLinewidth,color=colorList[4])

	if(index!=4):
		ax1.plot([0,0.5],iPEPSList[index]*np.ones(2),label="iPEPS",markersize=myMarkersize,marker="d",linestyle="solid",color="black")

	ax1.set_xlabel("$K/J$")
	ax1.set_ylabel(r"$e_0/J$")
	
	ax1.set_xlim([0.0,0.5])
	if(index==0):
		ax1.set_ylim([-1.012,-1.0])
		ax2.set_ylim([-1.006429,-1.006423])
		ax2.set_yticks([-1.006429,-1.006426,-1.006423])
	if(index==1):
		ax1.set_ylim([-1.1,-1.0])
		ax2.set_ylim([-1.0528,-1.0522])
		ax2.set_yticks(np.arange(-1.0538,-1.05219,0.0004))
	if(index==2):
		ax1.set_ylim([-1.3,-1.0])
		ax2.set_ylim([-1.140,-1.131])
		ax2.set_yticks(np.arange(-1.140,-1.1309,0.003))
	if(index==3):
		ax1.set_yticks(np.arange(-1.5,-0.99,0.1))
		ax1.set_ylim([-1.5,-1.0])
		ax2.set_ylim([-1.26,-1.23])
		ax2.set_yticks(np.arange(-1.26,-1.229,0.01))
	if(index==4):
		ax1.set_ylim([-1.6,-1.0])
	if(index==5):
		ax1.set_ylim([-1.6,-1.0])
	if(index==6):
		ax1.set_ylim([-1.7,-1.0])
		ax2.set_ylim([-1.42,-1.34])
		ax2.set_yticks(np.arange(-1.42,-1.339,0.02))
	if(index==7):
		ax1.set_ylim([-1.8,-1.0])
		ax2.set_ylim([-1.52,-1.40])

	ax2.get_yaxis().get_major_formatter().set_useOffset(False)

	# scaling as inset
	x=np.arange(0,0.07,0.001)

	invN=np.array([4,5,6])
	invN1=1/invN**2
	e0N1=np.array([min(e0_order4[1]),min(e0_order5[1][1:]),min(e0_order6[1])])/3
	p1=np.polyfit(invN1,e0N1,1)
	y1=p1[0]*x**1+p1[1]

	print("lambda={0}: Kmin_o4={1} Kmin_o5={2} Kmin_o6={3}".format(lambdaValue,e0_order4[0][e0_order4[1].argmin()],e0_order5[0][1+e0_order5[1][1:].argmin()],e0_order6[0][e0_order6[1].argmin()]))

	invN2=invN1[-2:]
	e0N2=e0N1[-2:]
	p2=np.polyfit(invN2,e0N2,1)
	y2=p2[0]*x**1+p2[1]
	pList[index]=p2[1]

	ax1.plot(invN1,e0N1*1000,marker="o",markersize=myMarkersize,linestyle="None",label="Min.",color=colorList[5])
	ax2.plot(x,y2,label="Skal.",color=colorList[5],linestyle="solid")
	ax2.plot(invN1,e0N1,marker="o",markersize=myMarkersize,linestyle="None",label="Min.",color=colorList[5])
	ax1.plot(x,y2*1000,label="Skal.",color=colorList[5],linewidth=myLinewidth,linestyle="solid")
	if(index!=4):
		ax2.plot([0],[iPEPSList[index]],marker="d",markersize=myMarkersize,linestyle="None",color="black",clip_on=False)

	ax2.set_xlabel(r"$1/N_\mathrm{dr}^2$")
	ax2.set_ylabel(r"$e_0/J$")
	ax2.set_xticks(np.arange(0, 0.076, 0.025))

	lgd=ax1.legend(loc="lower right",ncol=1, fontsize=myFontsize,fancybox=True)
	lgd.get_frame().set_linewidth(myLinewidth)
	plt.savefig("NLCE_kagomeOne_lambda{0}_da.pdf".format(lambdaValue))
	plt.clf()
	
	index=index+1

### lambda plot ###
plt.figure()
fig, ax1 = plt.subplots(figsize=(myFigsize_x,myFigsize_y))
# These are in unitless percentages of the figure size. (0,0 is bottom left)
left, bottom, width, height = [0.29, 0.23, 0.3, 0.3]
ax2 = fig.add_axes([left, bottom, width, height])
### K=0 ###
e0_order2=np.loadtxt("results_kagomeOne_fullExpansion_lambda/e0_order2_K0.txt",unpack=True)
e0_order3=np.loadtxt("results_kagomeOne_fullExpansion_lambda/e0_order3_K0.txt",unpack=True)
e0_order4=np.loadtxt("results_kagomeOne_fullExpansion_lambda/e0_order4_K0.txt",unpack=True)
e0_order5=np.loadtxt("results_kagomeOne_fullExpansion_lambda/e0_order5_K0.txt",unpack=True)
e0_order6=np.loadtxt("results_kagomeOne_fullExpansion_lambda/e0_order6_K0.txt",unpack=True)

ax1.plot(e0_order2[0],e0_order2[1]/3,label=r"$N_\mathrm{dr}=2$, $K/J=0$",color=colorList[0],marker="^",linewidth=myLinewidth,markersize=myMarkersize)
ax1.plot(e0_order3[0],e0_order3[1]/3,label=r"$N_\mathrm{dr}=3$, $K/J=0$",color=colorList[1],marker="^",linewidth=myLinewidth,markersize=myMarkersize)
ax1.plot(e0_order4[0],e0_order4[1]/3,label=r"$N_\mathrm{dr}=4$, $K/J=0$",color=colorList[2],marker="^",linewidth=myLinewidth,markersize=myMarkersize)
ax1.plot(e0_order5[0],e0_order5[1]/3,label=r"$N_\mathrm{dr}=5$, $K/J=0$",color=colorList[3],marker="^",linewidth=myLinewidth,markersize=myMarkersize)
ax1.plot(e0_order6[0],e0_order6[1]/3,label=r"$N_\mathrm{dr}=6$, $K/J=0$",color=colorList[4],marker="^",linewidth=myLinewidth,markersize=myMarkersize)


### K=0.05 ###
e0_order2=np.loadtxt("results_kagomeOne_fullExpansion_lambda/e0_order2_K0.05.txt",unpack=True)
e0_order3=np.loadtxt("results_kagomeOne_fullExpansion_lambda/e0_order3_K0.05.txt",unpack=True)
e0_order4=np.loadtxt("results_kagomeOne_fullExpansion_lambda/e0_order4_K0.05.txt",unpack=True)
e0_order5=np.loadtxt("results_kagomeOne_fullExpansion_lambda/e0_order5_K0.05.txt",unpack=True)
e0_order6=np.loadtxt("results_kagomeOne_fullExpansion_lambda/e0_order6_K0.05.txt",unpack=True)

ax1.plot(e0_order2[0],e0_order2[1]/3,label=r"$N_\mathrm{dr}=2$, $K/J=0.05$",color=colorList[0],marker="o",linewidth=myLinewidth,markersize=myMarkersize)
ax1.plot(e0_order3[0],e0_order3[1]/3,label=r"$N_\mathrm{dr}=3$, $K/J=0.05$",color=colorList[1],marker="o",linewidth=myLinewidth,markersize=myMarkersize)
ax1.plot(e0_order4[0],e0_order4[1]/3,label=r"$N_\mathrm{dr}=4$, $K/J=0.05$",color=colorList[2],marker="o",linewidth=myLinewidth,markersize=myMarkersize)
ax1.plot(e0_order5[0],e0_order5[1]/3,label=r"$N_\mathrm{dr}=5$, $K/J=0.05$",color=colorList[3],marker="o",linewidth=myLinewidth,markersize=myMarkersize)
ax1.plot(e0_order6[0],e0_order6[1]/3,label=r"$N_\mathrm{dr}=6$, $K/J=0.05$",color=colorList[4],marker="o",linewidth=myLinewidth,markersize=myMarkersize)

iPEPS=np.loadtxt("results_kagomeOne_iPEPS.txt",unpack=True)
ax1.plot(iPEPS[0],iPEPS[3],label="iPEPS",color="black")

ax1.plot(lambdaList,pList,label="Skal.", color="black", marker="s",linestyle="None",markersize=myMarkersize)
print(pList)

bestReorganized=np.loadtxt("results_kagomeOne_reorganizedExpansion_bestWynn.txt",unpack=True)
ax1.plot(bestReorganized[0],bestReorganized[1],label="$e_{1,\mathrm{even}}^{(2)}$",color="red",marker="*",linestyle="None",markersize=myMarkersize+1)

pList_iPEPSValues=np.array([pList[0]-iPEPS[3][3],pList[1]-iPEPS[3][8],pList[2]-iPEPS[3][13],pList[3]-iPEPS[3][18],pList[5]-iPEPS[3][21],pList[6]-iPEPS[3][23],pList[7]-iPEPS[3][26]])
lambdaList_iPEPSValues=[0.1,0.3,0.5,0.7,0.82,0.9,1.0]
ax2.plot(lambdaList_iPEPSValues,abs(pList_iPEPSValues),label="Skal.", markersize=myMarkersize, color="black", marker="s",linestyle="None")

bestReorganized_iPEPSValues=np.loadtxt("results_kagomeOne_reorganizedExpansion_bestWynn_iPEPSValues.txt",unpack=True)
ax2.plot(bestReorganized_iPEPSValues[0],abs(bestReorganized_iPEPSValues[1]-iPEPS[3]),label="$e_{1,\mathrm{even}}^{(2)}$",color="red",marker="*",markersize=myMarkersize+1,linestyle="None")

ax2.set_yticks(np.arange(0,0.0041,0.001))

ax1.set_ylim([-1.7,-1.0])


ax1.set_xlabel("$\lambda$")
ax1.set_ylabel("$e_0/J$")
ax2.set_xlabel("$\lambda$")
ax2.set_ylabel(r"$\left|e_0-e_0^{\mathrm{iPEPS}}\right|/J$")
lgd=ax1.legend(loc="upper right",ncol=1,bbox_to_anchor=(1.5,1.025), fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)
plt.savefig("NLCE_kagomeOne_edgeFieldComparison_da.pdf")
plt.clf()
