import matplotlib.pyplot as plt
import numpy as np

myFontsize=8.0
myLinewidth=0.6
myMarkersize=2.5
myMarkersizeBig=4.0
myFigsize_x=4.15
myFigsize_y=3.1125*2.2
myTextOffset=-0.37
plt.rc("text",usetex=True)
plt.rc("font",family="serif")
plt.rc("font",serif="Computer Modern Roman")
plt.rc("font",size=myFontsize)
plt.rc("axes",linewidth=myLinewidth)

### GROUND-STATE ENERGY ###

f, (ax1, ax2) = plt.subplots(2, sharex=False, sharey=False,figsize=(myFigsize_x, myFigsize_y)) #share x- and y-axis

markerList=["o","s","d","^","v"]
colorList=["blue","green","red","cyan","magenta","orange","black"]

### square expansion ###
e0_square=[]
e0_squareAboutMin=[]
e0_squareFix=np.zeros(3)
colorIndex=0
for order in np.arange(2,5):
	e0temp=np.loadtxt("results_squareOne_squareExpansion_order4/e0_order{0}.txt".format(order),unpack=True)
	e0_square.append(e0temp)
	ax1.plot(e0temp[0][:4],e0temp[1][:4],label="Ord. ${0}$".format(order),marker="o",markersize=myMarkersize,linewidth=myLinewidth,color=colorList[colorIndex])
	ax1.plot(e0temp[0][7:],e0temp[1][7:],marker="o",markersize=myMarkersize,linewidth=myLinewidth,color=colorList[colorIndex])
	e0temp=np.loadtxt("results_squareOne_squareExpansion_order4/e0_order{0}_aboutMin.txt".format(order),unpack=True)
	e0_squareAboutMin.append(e0temp)
	ax1.plot(e0temp[0],e0temp[1],marker="o",markersize=myMarkersize,linewidth=myLinewidth,color=colorList[colorIndex])
	colorIndex=colorIndex+1
	e0temp=np.loadtxt("selfConsistentResults/order{0}/e0_order{0}.txt".format(order),unpack=True)
	e0_squareFix[order-2]=e0temp[1][-1]

ax1.plot(e0_square[0][0],-2.32975*np.ones(len(e0_square[0][0])),label="CCM",color="black")
ax1.set_ylim([-2.4,-2.20])
ax1.text(myTextOffset,-2.20,"(a)",fontsize=10)
lgd=ax1.legend(loc="lower right",ncol=1,fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)

### magnetization ###
mag0_square=[]
mag0_squareAboutMin=[]
mag0_squareFix=np.zeros(3)
colorIndex=0
for order in np.arange(2,5):
	mag0temp=np.loadtxt("results_squareOne_squareExpansion_order4/mag0_order{0}.txt".format(order),unpack=True)
	mag0_square.append(mag0temp)
	ax2.plot(mag0temp[0][:4],mag0temp[1][:4]/2,label="Ord. ${0}$".format(order),marker="o",markersize=myMarkersize,linewidth=myLinewidth,color=colorList[colorIndex])
	ax2.plot(mag0temp[0][7:],mag0temp[1][7:]/2,marker="o",markersize=myMarkersize,linewidth=myLinewidth,color=colorList[colorIndex])
	mag0temp=np.loadtxt("results_squareOne_squareExpansion_order4/mag0_order{0}_aboutMin.txt".format(order),unpack=True)
	mag0_squareAboutMin.append(mag0temp)
	ax2.plot(mag0temp[0],mag0temp[1]/2,marker="o",markersize=myMarkersize,linewidth=myLinewidth,color=colorList[colorIndex])
	colorIndex=colorIndex+1
	mag0temp=np.loadtxt("selfConsistentResults/order{0}/mag0_order{0}.txt".format(order),unpack=True)
	mag0_squareFix[order-2]=mag0temp[1][-1]

ax2.plot(mag0_square[0][0],0.7938*np.ones(len(mag0_square[0][0])),label="CCM",color="black")
ax2.set_ylim([0.0,1.0])
ax2.text(myTextOffset,1.0,"(b)",fontsize=10)
lgd=ax2.legend(loc="lower right",ncol=1,fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)

ax1.set_xlabel("$K/J$")
ax2.set_xlabel("$K/J$")
ax1.set_ylabel("$e_0/J$")
ax2.set_ylabel("$m_0$")

plt.savefig("NLCE_squareOne_squareExpansion_gse_mag_da.pdf")
plt.clf()
#################################################

f, (ax1_inset, ax2_inset) = plt.subplots(2, sharex=False, sharey=False,figsize=(myFigsize_x, myFigsize_y)) #share x- and y-axis

### e0 scaling ###
invN1=np.array([2,3,4])
invN1=1/invN1
e0Min1=[min(e0_squareAboutMin[0][1]),min(e0_squareAboutMin[1][1]),min(e0_squareAboutMin[2][1])]
x=np.arange(0,invN1[0]+0.01,0.01)
#minimum QMC
invN2=invN1[-2::]**3
e0Min2=e0Min1[-2::]
p2=np.polyfit(invN2,e0Min2,1)
y2QMC=p2[0]*x**3+p2[1]
print("e0QMC")
print(p2[1])
print(p2[1]+2.32975)
#minimum CCM
invN2=invN1[-2::]**4
e0Min2=e0Min1[-2::]
p2=np.polyfit(invN2,e0Min2,1)
y2CCM=p2[0]*x**4+p2[1]
print("e0CCM")
print(p2[1])
print(p2[1]+2.32975)

#fixpoint QMC
invN2=invN1[-2::]**3
e0Min2=e0_squareFix[-2::]
p2=np.polyfit(invN2,e0Min2,1)
y2FixQMC=p2[0]*x**3+p2[1]
print("e0FixQMC")
print(p2[1])
print(p2[1]+2.32975)
#fixpoint CCM
invN2=invN1[-2::]**4
e0Min2=e0_squareFix[-2::]
p2=np.polyfit(invN2,e0Min2,1)
y2FixCCM=p2[0]*x**4+p2[1]
print("e0FixCCM")
print(p2[1])
print(p2[1]+2.32975)


ax1_inset.plot(invN1,e0_squareFix,marker="s",markersize=myMarkersizeBig,color="red",linestyle="None",label="Fix.")
ax1_inset.plot(x,y2FixQMC,color="red",linestyle="solid",linewidth=myLinewidth,label="Skal. (i)")
ax1_inset.plot(x,y2FixCCM,color="red",linestyle="dashed",linewidth=myLinewidth,label="Skal. (ii)")
ax1_inset.plot(invN1,e0Min1,marker="o",markersize=myMarkersizeBig,color="cyan",linestyle="None",label="Min.")
ax1_inset.plot(x,y2QMC,color="cyan",linestyle="solid",linewidth=myLinewidth,label="Skal. (i)")
ax1_inset.plot(x,y2CCM,color="cyan",linestyle="dashed",linewidth=myLinewidth,label="Skal. (ii)")
ax1_inset.plot([0],[-2.32975],marker="d",markersize=myMarkersizeBig,color="black",linestyle="None",label="CCM",clip_on=False)
ax1_inset.set_xlabel(r"$1/l$")
ax1_inset.set_ylabel(r"$e_0/J$")
ax1_inset.set_xlim([0,0.5001])
ax1_inset.set_ylim([-2.4,-2.3])
ax1_inset.text(myTextOffset/2*0.5,-2.3,"(a)",fontsize=10)
lgd=ax1_inset.legend(loc="lower left",ncol=2,fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)


### mag0 scaling ###
invN1=np.array([2,3,4])
invN1=1/invN1
mag0Min1=np.array([mag0_squareAboutMin[0][1][e0_squareAboutMin[0][1].argmin()],mag0_squareAboutMin[1][1][e0_squareAboutMin[1][1].argmin()],mag0_squareAboutMin[2][1][e0_squareAboutMin[2][1].argmin()]])

#minimum QMC
invN2=invN1[-2::]
mag0Min2=(mag0Min1[-2::]/2)**2
p2=np.polyfit(invN2,mag0Min2,1)
x=np.arange(0,invN1[0]+0.01,0.01)
y2QMC=p2[0]*x+p2[1]
y2QMC=np.sqrt(y2QMC)
print("mag0QMC")
print(np.sqrt(p2[1]))
print(np.sqrt(p2[1])-0.7938)
#minimum CCM
invN2=invN1[-2::]
mag0Min2=(mag0Min1[-2::]/2)
p2=np.polyfit(invN2**2,mag0Min2,1)
x=np.arange(0,invN1[0]+0.01,0.01)
y2CCM=p2[0]*x**2+p2[1]
print("mag0CCM")
print(p2[1])
print(p2[1]-0.7938)

#fixpoint QMC
invN2=invN1[-2::]
mag0Min2=(mag0_squareFix[-2::]/2)**2
p2=np.polyfit(invN2,mag0Min2,1)
x=np.arange(0,invN1[0]+0.01,0.01)
y2FixQMC=p2[0]*x+p2[1]
y2FixQMC=np.sqrt(y2FixQMC)
print("mag0FixQMC")
print(np.sqrt(p2[1]))
print(np.sqrt(p2[1])-0.7938)
#fixpoint CCM
invN2=invN1[-2::]
mag0Min2=(mag0_squareFix[-2::]/2)
p2=np.polyfit(invN2**2,mag0Min2,1)
x=np.arange(0,invN1[0]+0.01,0.01)
y2FixCCM=p2[0]*x**2+p2[1]
print("mag0FixCCM")
print(p2[1])
print(p2[1]-0.7938)


ax2_inset.plot(invN1,np.array(mag0_squareFix)/2,marker="s",markersize=myMarkersizeBig,color="red",linestyle="None",label="Fix.")
ax2_inset.plot(x,y2FixQMC,color="red",linestyle="solid",linewidth=myLinewidth,label="Skal. (i)")
ax2_inset.plot(x,y2FixCCM,color="red",linestyle="dashed",linewidth=myLinewidth,label="Skal. (ii)")
ax2_inset.plot(invN1,np.array(mag0Min1)/2,marker="o",markersize=myMarkersizeBig,color="cyan",linestyle="None",label="Min.")
ax2_inset.plot(x,y2QMC,color="cyan",linestyle="solid",linewidth=myLinewidth,label="Skal. (i)")
ax2_inset.plot(x,y2CCM,color="cyan",linestyle="dashed",linewidth=myLinewidth,label="Skal. (ii)")
ax2_inset.plot([0],[0.7938],marker="d",markersize=myMarkersizeBig,color="black",linestyle="None",label="CCM",clip_on=False)
ax2_inset.set_xlabel("$1/l$")
ax2_inset.set_ylabel("$m_0$")
ax2_inset.set_xlim([0,0.5001])
ax2_inset.set_ylim([0.0,1.0])
ax2_inset.text(myTextOffset/2*0.5,1.0,"(b)",fontsize=10)
lgd=ax2_inset.legend(loc="lower left",ncol=2,fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)

plt.savefig("NLCE_squareOne_squareExpansion_gse_mag_scaling_da.pdf")
plt.clf()


