import matplotlib.pyplot as plt
import numpy as np

myFontsize=8.0
myLinewidth=0.6
myMarkersize=2.5
myFigsize_x=4.15
myFigsize_y=3.1125
myTextOffset=-0.37
plt.rc("text",usetex=True)
plt.rc("font",family="serif")
plt.rc("font",serif="Computer Modern Roman")
plt.rc("font",size=myFontsize)
plt.rc("axes",linewidth=myLinewidth)

markerList=["o","s","d","^","v"]
colorList=["blue","green","red","cyan","magenta","orange","black"]

### GROUND-STATE ENERGY ###

f, (ax1) = plt.subplots(1, sharex=False, sharey=False,figsize=(myFigsize_x, myFigsize_y))
### full expansion ###
e0_order2=np.loadtxt("results_squareOneHalf_fullExpansion_order8/e0_order2.txt",unpack=True)
e0_order3=np.loadtxt("results_squareOneHalf_fullExpansion_order8/e0_order3.txt",unpack=True)
e0_order4=np.loadtxt("results_squareOneHalf_fullExpansion_order8/e0_order4.txt",unpack=True)
e0_order5=np.loadtxt("results_squareOneHalf_fullExpansion_order8/e0_order5.txt",unpack=True)
e0_order6=np.loadtxt("results_squareOneHalf_fullExpansion_order8/e0_order6.txt",unpack=True)
e0_order7=np.loadtxt("results_squareOneHalf_fullExpansion_order8/e0_order7.txt",unpack=True)
e0_order8=np.loadtxt("results_squareOneHalf_fullExpansion_order8/e0_order8.txt",unpack=True)

ax1.plot(e0_order2[0],e0_order2[1],label="Ord. $2$",marker="o",color=colorList[0],linewidth=myLinewidth,markersize=myMarkersize)
ax1.plot(e0_order3[0],e0_order3[1],label="Ord. $3$",marker="o",color=colorList[1],linewidth=myLinewidth,markersize=myMarkersize)
ax1.plot(e0_order4[0],e0_order4[1],label="Ord. $4$",marker="o",color=colorList[2],linewidth=myLinewidth,markersize=myMarkersize)
ax1.plot(e0_order5[0],e0_order5[1],label="Ord. $5$",marker="o",color=colorList[3],linewidth=myLinewidth,markersize=myMarkersize)
ax1.plot(e0_order6[0],e0_order6[1],label="Ord. $6$",marker="o",color=colorList[4],linewidth=myLinewidth,markersize=myMarkersize)
ax1.plot(e0_order7[0],e0_order7[1],label="Ord. $7$",marker="o",color=colorList[5],linewidth=myLinewidth,markersize=myMarkersize)
ax1.plot(e0_order8[0],e0_order8[1],label="Ord. $8$",marker="o",color=colorList[6],linewidth=myLinewidth,markersize=myMarkersize)
ax1.plot(e0_order2[0],-0.669437*np.ones(len(e0_order2[0])),label="QMC",color="black")
lgd=ax1.legend(loc="upper left",ncol=2,fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)
ax1.set_ylim([-0.7,-0.52])
ax1.set_xlabel("$K/J$")
ax1.set_ylabel("$e_0/J$")
plt.savefig("NLCE_squareOneHalf_fullExpansion_gse_da.pdf")
plt.clf()

### rectangular expansion ###
f, (ax2) = plt.subplots(1, sharex=False, sharey=False,figsize=(myFigsize_x, myFigsize_y))
e0_rectangular=[]
e0_rectangularAboutMin=[]
colorIndex=0
for order in np.arange(2,26):
	e0temp=np.loadtxt("results_squareOneHalf_rectangularExpansion_order25/e0_order{0}.txt".format(order),unpack=True)
	e0_rectangular.append(e0temp)
	if(order>=9):
		ax2.plot(e0temp[0][5:],e0temp[1][5:],label="Ord. ${0}$".format(order),marker=markerList[(order-2)//5],linewidth=myLinewidth,markersize=myMarkersize,color=colorList[colorIndex%7])

	e0temp=np.loadtxt("results_squareOneHalf_rectangularExpansion_order25/e0_order{0}_aboutMin.txt".format(order),unpack=True)
	e0temp2=np.loadtxt("results_squareOneHalf_rectangularExpansion_order25/e0_order{0}_aboutMin2.txt".format(order),unpack=True)
	test1=np.array(e0temp2[0])
	test2=np.array(e0temp[0])
	test3_0=np.concatenate((test1,test2),axis=0)
	test1=np.array(e0temp2[1])
	test2=np.array(e0temp[1])
	test3_1=np.concatenate((test1,test2),axis=0)
	e0_rectangularAboutMin.append([test3_0,test3_1])
	if(order>=9):
		ax2.plot(test3_0,test3_1,marker=markerList[(order-2)//5],markersize=myMarkersize,linewidth=myLinewidth,color=colorList[colorIndex%7])
	colorIndex=colorIndex+1
	

ax2.plot(e0_rectangular[0][0],-0.669437*np.ones(len(e0_rectangular[0][0])),label="QMC",color="black")
ax2.set_ylim([-0.676,-0.664])
lgd=ax2.legend(loc="lower right",ncol=2,fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)
ax2.set_xlabel("$K/J$")
ax2.set_ylabel("$e_0/J$")

plt.savefig("NLCE_squareOneHalf_rectangularExpansion_gse_da.pdf")
plt.clf()
##########################################################

f, (ax3) = plt.subplots(1, sharex=False, sharey=False,figsize=(myFigsize_x, myFigsize_y))
### arithmetic expansion ###
e0_arithmetic=[]
e0_arithmeticAboutMin=[]
colorIndex=0
for order in np.arange(1,9):
	e0temp=np.loadtxt("results_squareOneHalf_arithmeticExpansion_order8/e0_order{0}.txt".format(order),unpack=True)
	e0_arithmetic.append(e0temp)
	ax3.plot(e0temp[0][5:],e0temp[1][5:],label="Ord. ${0}$".format(order),markersize=myMarkersize,linewidth=myLinewidth,marker=markerList[(order-1)//5],color=colorList[colorIndex%7])
	e0temp=np.loadtxt("results_squareOneHalf_arithmeticExpansion_order8/e0_order{0}_aboutMin.txt".format(order),unpack=True)
	e0_arithmeticAboutMin.append(e0temp)
	ax3.plot(e0temp[0],e0temp[1],marker=markerList[(order-1)//5],markersize=myMarkersize,linewidth=myLinewidth,color=colorList[colorIndex%7])
	colorIndex=colorIndex+1
						
ax3.plot(e0_arithmetic[0][0],-0.669437*np.ones(len(e0_arithmetic[0][0])),label="QMC",color="black")
ax3.set_ylim([-0.68,-0.65])
lgd=ax3.legend(loc="lower right",ncol=2,fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)
ax3.set_xlabel("$K/J$")
ax3.set_ylabel("$e_0/J$")
plt.savefig("NLCE_squareOneHalf_arithmeticExpansion_gse_da.pdf")
plt.clf()

### square expansion ###
f, (ax4) = plt.subplots(1, sharex=False, sharey=False,figsize=(myFigsize_x, myFigsize_y))
e0_square=[]
e0_squareAboutMin=[]
colorIndex=0
for order in np.arange(2,6):
	e0temp=np.loadtxt("results_squareOneHalf_squareExpansion_order5/e0_order{0}.txt".format(order),unpack=True)
	e0_square.append(e0temp)
	ax4.plot(e0temp[0][6:],e0temp[1][6:],label="Ord. ${0}$".format(order),markersize=myMarkersize,linewidth=myLinewidth,marker="o",color=colorList[colorIndex])
	e0temp=np.loadtxt("results_squareOneHalf_squareExpansion_order5/e0_order{0}_aboutMin.txt".format(order),unpack=True)
	e0_squareAboutMin.append(e0temp)
	ax4.plot(e0temp[0],e0temp[1],marker="o",markersize=myMarkersize,linewidth=myLinewidth,color=colorList[colorIndex])
	colorIndex=colorIndex+1
						
ax4.plot(e0_square[0][0],-0.669437*np.ones(len(e0_square[0][0])),label="QMC",color="black")
ax4.set_ylim([-0.68,-0.65])
lgd=ax4.legend(loc="lower right",ncol=2,fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)
ax4.set_xlabel("$K/J$")
ax4.set_ylabel("$e_0/J$")

plt.savefig("NLCE_squareOneHalf_squareExpansion_gse_da.pdf")
plt.clf()
##########################################################

### SCALING OF GSE ###
plt.figure()
fig, (ax1,ax3) = plt.subplots(2,sharex=False, sharey=False,figsize=(myFigsize_x,myFigsize_y))

# These are in unitless percentages of the figure size. (0,0 is bottom left)
left, bottom, width, height = [0.29, 0.72, 0.28, 0.15]
ax2 = fig.add_axes([left, bottom, width, height])

x=np.arange(0,0.5+0.001,0.001)

### scaling of self-consistent expansions ###
# arithmetic expansion
print("self-consistent arithmetic expansion:")
invNarithmetic1=np.array([2,4,5,6,7,8])
e0arithmeticFix1=np.zeros(len(invNarithmetic1))
index=0
for N in invNarithmetic1:
    e0temp=np.loadtxt("results_squareOneHalf_selfConsistentArithmetic/order{0}/e0_order{0}.txt".format(N),unpack=True)
    e0arithmeticFix1[index]=e0temp[1][-1]
    index=index+1
invNarithmetic1=(2/(invNarithmetic1+2))

invNarithmetic2=invNarithmetic1[1::2]
e0arithmeticFix2=e0arithmeticFix1[1::2]

A=np.vstack([invNarithmetic2**4,invNarithmetic2**3,np.ones(len(invNarithmetic2))]).T
p2=np.linalg.lstsq(A,e0arithmeticFix2)[0]
yQMC=p2[0]*x**4+p2[1]*x**3+p2[2]
print("e0scaledQMC={0}".format(p2[2]))
print(p2[2]+0.669437)

A=np.vstack([invNarithmetic2**8,invNarithmetic2**4,np.ones(len(invNarithmetic2))]).T
p2=np.linalg.lstsq(A,e0arithmeticFix2)[0]
yCCM=p2[0]*x**8+p2[1]*x**4+p2[2]
print("e0scaledCCM={0}".format(p2[2]))
print(p2[2]+0.669437)

ax1.plot(invNarithmetic1,e0arithmeticFix1,marker="s",markersize=myMarkersize,color="red",linestyle="None",label="arith. (Fix.)")
ax1.plot(x,yQMC,color="red",linestyle="dashed",linewidth=myLinewidth,label="Skal. arith. (Fix.)")

ax3.plot(invNarithmetic1,e0arithmeticFix1,marker="s",markersize=myMarkersize,color="red",linestyle="None",label="arith. (Fix.)")
ax3.plot(x,yCCM,color="red",linestyle="dashed",linewidth=myLinewidth,label="Skal. arith. (Fix.)")

# square expansion
print("\nself-consistent square expansion:")
invNsquare1=np.array([2,3,4,5])
e0squareFix1=np.array([-0.67418,-0.664078,-0.668375,-0.668479])
invNsquare1=1/invNsquare1

invNsquare2=invNsquare1[1::2]
e0squareFix2=e0squareFix1[1::2]

A=np.vstack([invNsquare2**3,np.ones(len(invNsquare2))]).T
p2=np.linalg.lstsq(A,e0squareFix2)[0]
yQMC=p2[0]*x**3+p2[1]
print("e0scaledQMC={0}".format(p2[1]))
print(p2[1]+0.669437)

A=np.vstack([invNsquare2**4,np.ones(len(invNsquare2))]).T
p2=np.linalg.lstsq(A,e0squareFix2)[0]
yCCM=p2[0]*x**4+p2[1]
print("e0scaledCCM={0}".format(p2[1]))
print(p2[1]+0.669437)

ax1.plot(invNsquare1,e0squareFix1,marker="s",markersize=myMarkersize,color="green",linestyle="None",label="Quad. (Fix.)")
ax1.plot(x,yQMC,color="green",linestyle="dashed",linewidth=myLinewidth,label=r"Skal. Quad. (Fix.)")

ax3.plot(invNsquare1,e0squareFix1,marker="s",markersize=myMarkersize,color="green",linestyle="None",label="Quad. (Fix.)")
ax3.plot(x,yCCM,color="green",linestyle="dashed",linewidth=myLinewidth,label=r"Skal. Quad. (Fix.)")

### MINIMUM METHOD ###
### arithmetic expansion ###
print("\nminimum arithmetic expansion:")
invN1=np.array([2,4,6,8])
invN1=(2/(invN1+2))
e0Min1=[min(e0_arithmeticAboutMin[1][1]),min(e0_arithmeticAboutMin[3][1]),min(e0_arithmeticAboutMin[5][1]),min(e0_arithmeticAboutMin[7][1])]
print("order2: Kmin={0}".format(e0_arithmeticAboutMin[1][0][e0_arithmeticAboutMin[1][1].argmin()]))
print("order4: Kmin={0}".format(e0_arithmeticAboutMin[3][0][e0_arithmeticAboutMin[3][1].argmin()]))
print("order6: Kmin={0}".format(e0_arithmeticAboutMin[5][0][e0_arithmeticAboutMin[5][1].argmin()]))
print("order8: Kmin={0}".format(e0_arithmeticAboutMin[7][0][e0_arithmeticAboutMin[7][1].argmin()]))

invN2=invN1[1::]
e0Min2=e0Min1[1::]

A=np.vstack([invN2**4,invN2**3,np.ones(len(invN2))]).T
p2=np.linalg.lstsq(A,e0Min2)[0]
yQMC=p2[0]*x**4+p2[1]*x**3+p2[2]
print("e0scaledQMC={0}".format(p2[2]))
print(p2[2]+0.669437)

A=np.vstack([invN2**8,invN2**4,np.ones(len(invN2))]).T
p2=np.linalg.lstsq(A,e0Min2)[0]
y2=p2[0]*x**8+p2[1]*x**4+p2[2]
print("e0scaledCCM={0}".format(p2[2]))
print(p2[2]+0.669437)

ax1.plot(invN1,e0Min1,marker="o",markersize=myMarkersize,color="red",linestyle="None",label="arith. (Min.)")
ax1.plot(x,yQMC,color="red",linestyle="solid",linewidth=myLinewidth,label="Skal. arith. (Min.)")

ax3.plot(invN1,e0Min1,marker="o",markersize=myMarkersize,color="red",linestyle="None",label="arith. (Min.)")
ax3.plot(x,yCCM,color="red",linestyle="solid",linewidth=myLinewidth,label="Skal. arith. (Min.)")

### square expansion ###
print("\nminimum square expansion:")
invN1=np.array([2,3,4,5])
invN1=1/invN1
e0Min1=[min(e0_squareAboutMin[0][1]),min(e0_squareAboutMin[1][1]),min(e0_squareAboutMin[2][1]),min(e0_squareAboutMin[3][1])]
print("order2: {0}".format(e0_squareAboutMin[0][0][e0_squareAboutMin[0][1].argmin()]))
print("order3: {0}".format(e0_squareAboutMin[1][0][e0_squareAboutMin[1][1].argmin()]))
print("order4: {0}".format(e0_squareAboutMin[2][0][e0_squareAboutMin[2][1].argmin()]))
print("order5: {0}".format(e0_squareAboutMin[3][0][e0_squareAboutMin[3][1].argmin()]))

invN2=invN1[1::2]
e0Min2=e0Min1[1::2]

A=np.vstack([invN2**3,np.ones(len(invN2))]).T
p2=np.linalg.lstsq(A,e0Min2)[0]
yQMC=p2[0]*x**3+p2[1]
print("e0scaledQMC={0}".format(p2[1]))
print(p2[1]+0.669437)

A=np.vstack([invN2**4,np.ones(len(invN2))]).T
p2=np.linalg.lstsq(A,e0Min2)[0]
yCCM=p2[0]*x**4+p2[1]
print("e0scaledCCM={0}".format(p2[1]))
print(p2[1]+0.669437)

ax1.plot(invN1,e0Min1,marker="o",markersize=myMarkersize,color="green",linestyle="None",label="Quad. (Min.)")
ax1.plot(x,yQMC,color="green",linestyle="solid",linewidth=myLinewidth,label="Skal. Quad. (Min.)")

ax3.plot(invN1,e0Min1,marker="o",markersize=myMarkersize,color="green",linestyle="None",label="Quad. (Min.)")
ax3.plot(x,yCCM,color="green",linestyle="solid",linewidth=myLinewidth,label="Skal. Quad. (Min.)")


### rectangular expansion (as inset) ###
print("rectangular expansion:")
invN1=np.array([9,10,11,15,16,17,18,19,25])
x=np.arange(0,0.4,0.001)
e0Min1=np.zeros(len(invN1))
j=0
arrayShift=10
for i in invN1:
	print("order {0}: {1}".format(i,e0_rectangularAboutMin[i-2][0][arrayShift+e0_rectangularAboutMin[i-2][1][arrayShift:].argmin()]))
	e0Min1[j]=min(e0_rectangularAboutMin[i-2][1][10:])
	j=j+1

invN1=1/np.sqrt(invN1)

invN2=invN1
e0Min2=e0Min1

A=np.vstack([invN2**4,invN2**3,np.ones(len(invN2))]).T
p2=np.linalg.lstsq(A,e0Min2)[0]
y2=p2[0]*x**4+p2[1]*x**3+p2[2]

ax1.plot(invN1,e0Min1*1000,marker="o",markersize=myMarkersize,color="blue",linestyle="None",label="Recht. (Min.)")
ax1.plot(x,1000*y2,color="blue",linestyle="solid",linewidth=myLinewidth,label="Skal. Recht. (Min.)")
ax2.plot(invN1,e0Min1,marker="o",markersize=myMarkersize,color="blue",linestyle="None",label="Recht. (Min.)")
ax2.plot(x,y2,color="blue",linestyle="solid",linewidth=myLinewidth,label="Skal. Recht. (Min.)")

ax2.set_xlim([0,0.5])
ax2.set_xticks(np.arange(0,0.51,0.1))
ax2.set_ylim([-0.67,-0.664])
ax2.set_yticks(np.arange(-0.670,-0.6639,0.002))
ax2.set_xlabel(r"$1/l$")
ax2.set_ylabel("$e_0/J$")

# general plot parameters

ax1.plot([0],[-0.669437],marker="d",markersize=myMarkersize,color="black",linestyle="None",label="QMC",clip_on=False)
ax1.set_xlim([0,0.5])
ax1.set_ylim([-0.68,-0.64])
ax1.text(myTextOffset/4,-0.64,"(a)",fontsize=10)
ax1.set_xlabel("$1/l$")
ax1.set_ylabel("$e_0/J$")
lgd=ax1.legend(loc="upper left",bbox_to_anchor=(1.01, 1.02),ncol=1,fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)

ax3.plot([0],[-0.669437],marker="d",markersize=myMarkersize,color="black",linestyle="None",label="QMC",clip_on=False)
ax3.set_xlim([0,0.5])
ax3.set_ylim([-0.68,-0.64])
ax3.text(myTextOffset/4,-0.64,"(b)",fontsize=10)
ax3.set_xlabel("$1/l$")
ax3.set_ylabel("$e_0/J$")

ax1.text(0.02,-0.675,"Skal. (i)",fontsize=10)
ax3.text(0.02,-0.675,"Skal. (ii)",fontsize=10)

plt.savefig("NLCE_squareOneHalf_gse_scaling_da.pdf")
plt.clf()
