import matplotlib.pyplot as plt
import numpy as np

myFontsize=8.0
myLinewidth=0.6
myMarkersize=2.5
myFigsize_x=4.15
myFigsize_y=3.1125*2.2
myTextOffset=-0.37

plt.rc("text",usetex=True)
plt.rc("font",family="serif")
plt.rc("font",serif="Computer Modern Roman")
plt.rc("font",size=myFontsize)
plt.rc("axes",linewidth=myLinewidth)

markerList=["o","s","d","^","v"]
colorList=["blue","green","red","cyan","magenta","orange","black"]

### MAGNETIZATION ###
f, (ax1, ax2) = plt.subplots(2, sharex=False, sharey=False,figsize=(myFigsize_x,myFigsize_y))

### full expansion ###
mag0_order2=np.loadtxt("results_squareOneHalf_fullExpansion_order8/mag0_order2.txt",unpack=True)
mag0_order3=np.loadtxt("results_squareOneHalf_fullExpansion_order8/mag0_order3.txt",unpack=True)
mag0_order4=np.loadtxt("results_squareOneHalf_fullExpansion_order8/mag0_order4.txt",unpack=True)
mag0_order5=np.loadtxt("results_squareOneHalf_fullExpansion_order8/mag0_order5.txt",unpack=True)
mag0_order6=np.loadtxt("results_squareOneHalf_fullExpansion_order8/mag0_order6.txt",unpack=True)
mag0_order7=np.loadtxt("results_squareOneHalf_fullExpansion_order8/mag0_order7.txt",unpack=True)
mag0_order8=np.loadtxt("results_squareOneHalf_fullExpansion_order8/mag0_order8.txt",unpack=True)

ax1.plot(mag0_order2[0],mag0_order2[1]/2,label="Ord. $2$",marker="o",color=colorList[0],linewidth=myLinewidth,markersize=myMarkersize)
ax1.plot(mag0_order3[0],mag0_order3[1]/2,label="Ord. $3$",marker="o",color=colorList[1],linewidth=myLinewidth,markersize=myMarkersize)
ax1.plot(mag0_order4[0],mag0_order4[1]/2,label="Ord. $4$",marker="o",color=colorList[2],linewidth=myLinewidth,markersize=myMarkersize)
ax1.plot(mag0_order5[0],mag0_order5[1]/2,label="Ord. $5$",marker="o",color=colorList[3],linewidth=myLinewidth,markersize=myMarkersize)
ax1.plot(mag0_order6[0],mag0_order6[1]/2,label="Ord. $6$",marker="o",color=colorList[4],linewidth=myLinewidth,markersize=myMarkersize)
ax1.plot(mag0_order7[0],mag0_order7[1]/2,label="Ord. $7$",marker="o",color=colorList[5],linewidth=myLinewidth,markersize=myMarkersize)
ax1.plot(mag0_order8[0],mag0_order8[1]/2,label="Ord. $8$",marker="o",color=colorList[6],linewidth=myLinewidth,markersize=myMarkersize)
ax1.plot(mag0_order2[0],0.3070*np.ones(len(mag0_order2[0])),label="QMC",color="black")
lgd=ax1.legend(loc="lower right",ncol=2,fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)
ax1.set_ylim([0.0,0.5])
ax1.text(myTextOffset,0.5,"(a)",fontsize=10)
ax1.set_xlabel("$K/J$")
ax1.set_ylabel("$m_0$")

### rectangular expansion ###
mag0_rectangular=[]
mag0_rectangularAboutMin=[]
colorIndex=0
for order in np.arange(2,26):
	mag0temp=np.loadtxt("results_squareOneHalf_rectangularExpansion_order25/mag0_order{0}.txt".format(order),unpack=True)
	mag0_rectangular.append(mag0temp)
	if(order>=9):
		ax2.plot(mag0temp[0][:4],mag0temp[1][:4]/2,label="Ord. ${0}$".format(order),linewidth=myLinewidth,markersize=myMarkersize,marker=markerList[(order-2)//5],color=colorList[colorIndex%7])
		ax2.plot(mag0temp[0][5:],mag0temp[1][5:]/2,marker=markerList[(order-2)//5],linewidth=myLinewidth,markersize=myMarkersize,color=colorList[colorIndex%7])

	mag0temp=np.loadtxt("results_squareOneHalf_rectangularExpansion_order25/mag0_order{0}_aboutMin.txt".format(order),unpack=True)
	mag0_rectangularAboutMin.append(mag0temp)
	if(order>=9):
		ax2.plot(mag0temp[0],mag0temp[1]/2,linewidth=myLinewidth,markersize=myMarkersize,marker=markerList[(order-2)//5],color=colorList[colorIndex%7])
	colorIndex=colorIndex+1
	

ax2.plot(mag0_rectangular[0][0],0.3070*np.ones(len(mag0_rectangular[0][0])),label="QMC",color="black")
ax2.set_ylim([0.0,0.5])
ax2.text(myTextOffset,0.5,"(b)",fontsize=10)
lgd=ax2.legend(loc="lower right",ncol=2,fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)
ax2.set_ylim([0.0,0.5])
ax2.set_xlabel("$K/J$")
ax2.set_ylabel("$m_0$")

plt.savefig("NLCE_squareOneHalf_fullRectangular_mag_da.pdf")
plt.clf()
#########################################################

f, (ax3, ax4) = plt.subplots(2, sharex=False, sharey=False,figsize=(myFigsize_x, myFigsize_y))
### arithmetic expansion ###
mag0_arithmetic=[]
mag0_arithmeticAboutMin=[]
colorIndex=0
for order in np.arange(1,9):
	mag0temp=np.loadtxt("results_squareOneHalf_arithmeticExpansion_order8/mag0_order{0}.txt".format(order),unpack=True)
	mag0_arithmetic.append(mag0temp)
	ax3.plot(mag0temp[0][:4],mag0temp[1][:4]/2,linewidth=myLinewidth,markersize=myMarkersize,label="Ord. ${0}$".format(order),marker=markerList[(order-2)//5],color=colorList[colorIndex%7])
	ax3.plot(mag0temp[0][5:],mag0temp[1][5:]/2,marker=markerList[(order-2)//5],linewidth=myLinewidth,markersize=myMarkersize,color=colorList[colorIndex%7])

	mag0temp=np.loadtxt("results_squareOneHalf_arithmeticExpansion_order8/mag0_order{0}_aboutMin.txt".format(order),unpack=True)
	mag0_arithmeticAboutMin.append(mag0temp)
	ax3.plot(mag0temp[0],mag0temp[1]/2,linewidth=myLinewidth,markersize=myMarkersize,marker=markerList[(order-2)//5],color=colorList[colorIndex%7])
	colorIndex=colorIndex+1
	
ax3.plot(mag0_arithmetic[0][0],0.3070*np.ones(len(mag0_arithmetic[0][0])),label="QMC",color="black")
ax3.set_ylim([0.0,0.5])
ax3.text(myTextOffset,0.5,"(c)",fontsize=10)
lgd=ax3.legend(loc="lower right",ncol=2,fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)
ax3.set_ylim([0.0,0.5])
ax3.set_xlabel("$K/J$")
ax3.set_ylabel("$m_0$")

### square expansion ###
mag0_square=[]
mag0_squareAboutMin=[]
colorIndex=0
for order in np.arange(2,6):
	mag0temp=np.loadtxt("results_squareOneHalf_squareExpansion_order5/mag0_order{0}.txt".format(order),unpack=True)
	mag0_square.append(mag0temp)
	ax4.plot(mag0temp[0][6:],mag0temp[1][6:]/2,linewidth=myLinewidth,markersize=myMarkersize,label="Ord. ${0}$".format(order),marker="o",color=colorList[colorIndex])
	mag0temp=np.loadtxt("results_squareOneHalf_squareExpansion_order5/mag0_order{0}_aboutMin.txt".format(order),unpack=True)
	mag0_squareAboutMin.append(mag0temp)
	ax4.plot(mag0temp[0],mag0temp[1]/2,marker="o",linewidth=myLinewidth,markersize=myMarkersize,color=colorList[colorIndex])
	colorIndex=colorIndex+1
						
ax4.plot(mag0_square[0][0],0.3070*np.ones(len(mag0_square[0][0])),label="QMC",color="black")
ax4.set_ylim([0.0,0.5])
ax4.text(myTextOffset,0.5,"(d)",fontsize=10)
lgd=ax4.legend(loc="lower right",ncol=1,fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)
ax4.set_ylim([0.0,0.5])
ax4.set_xlabel("$K/J$")
ax4.set_ylabel("$m_0$")

plt.savefig("NLCE_squareOneHalf_arithmeticSquare_mag_da.pdf")
plt.clf()
#########################################################


### SCALING OF MAGNETIZATION ###
plt.figure()
fig, (ax1,ax3) = plt.subplots(2,sharex=False, sharey=False,figsize=(myFigsize_x,myFigsize_y))

# These are in unitless percentages of the figure size. (0,0 is bottom left)
x=np.arange(0,0.5+0.001,0.001)

### self-consistent scalings ###
# arithmetic expansion
print("self-consistent arithmetic expansion:")
invN1=np.array([2,4,5,6,7,8])
mag0Fix1=np.zeros(len(invN1))
index=0
for N in invN1:
    mag0temp=np.loadtxt("results_squareOneHalf_selfConsistentArithmetic/order{0}/mag0_order{0}.txt".format(N),unpack=True)
    mag0Fix1[index]=mag0temp[1][-1]
    index=index+1
invN1=2/(invN1+2)

invN2=invN1[1::2]
mag0Fix2=(mag0Fix1[1::2]/2)**2
A=np.vstack([invN2**2,invN2,np.ones(len(invN2))]).T
p2=np.linalg.lstsq(A,mag0Fix2)[0]
yQMC=p2[0]*x**2+p2[1]*x+p2[2]
yQMC=np.sqrt(yQMC)
print("mag0scaledQMC={0}".format(np.sqrt(p2[2])))
print(p2)
print(np.sqrt(p2[2])-0.3070)

mag0Fix2=(mag0Fix1[1::2]/2)
A=np.vstack([invN2**4,invN2**2,np.ones(len(invN2))]).T
p2=np.linalg.lstsq(A,mag0Fix2)[0]
yCCM=p2[0]*x**4+p2[1]*x**2+p2[2]
print("mag0scaledCCM={0}".format(p2[2]))
print(p2)
print(p2[2]-0.3070)

ax1.plot(invN1,(mag0Fix1/2),marker="s",markersize=myMarkersize,color="red",linestyle="None",label="arith. (Fix.)")
ax1.plot(x,yQMC,color="red",linestyle="dashed",linewidth=myLinewidth,label="Skal. arith. (Fix.)")

ax3.plot(invN1,(mag0Fix1/2),marker="s",markersize=myMarkersize,color="red",linestyle="None",label="arith. (Fix.)")
ax3.plot(x,yCCM,color="red",linestyle="dashed",linewidth=myLinewidth,label="Skal. arith. (Fix.)")

# square expansion
print("\nself-consistent square expansion")
invN1=np.array([2,3,4,5])
invN1=1/invN1
mag0Fix1=np.array([0.740645,0.751678,0.706889,0.697637])

invN2=invN1[1::2]
mag0Fix2=(mag0Fix1[1::2]/2)**2
A=np.vstack([invN2,np.ones(len(invN2))]).T
p2=np.linalg.lstsq(A,mag0Fix2)[0]
yQMC=p2[0]*x+p2[1]
yQMC=np.sqrt(yQMC)
print("mag0scaledQMC={0}".format(np.sqrt(p2[1])))
print(p2)
print(np.sqrt(p2[1])-0.3070)

mag0Fix2=(mag0Fix1[1::2]/2)
A=np.vstack([invN2**2,np.ones(len(invN2))]).T
p2=np.linalg.lstsq(A,mag0Fix2)[0]
yCCM=p2[0]*x**2+p2[1]
print("mag0scaledCCM={0}".format(p2[1]))
print(p2)
print(p2[1]-0.3070)

ax1.plot(invN1,(mag0Fix1/2),marker="s",markersize=myMarkersize,color="green",linestyle="None",label="Quad. (Fix.)")
ax1.plot(x,yQMC,color="green",linestyle="dashed",linewidth=myLinewidth,label="Skal. Quad. (Fix.)")

ax3.plot(invN1,(mag0Fix1/2),marker="s",markersize=myMarkersize,color="green",linestyle="None",label="Quad. (fix.)")
ax3.plot(x,yCCM,color="green",linestyle="dashed",linewidth=myLinewidth,label="Skal. Quad. (Fix.)")


### MINIMUM METHOD ###
### arithmetic expansion ###
print("\nminimum arithmetic expansion")
invN1=np.array([2,4,6,8])
mag0Min1=np.array([mag0_arithmeticAboutMin[1][1][20],mag0_arithmeticAboutMin[3][1][19],mag0_arithmeticAboutMin[5][1][13],mag0_arithmeticAboutMin[7][1][7]])

print("mag0Min1={0}".format(mag0Min1/2))

invN1=2/(invN1+2)

invN2=invN1[1::2]
mag0Min2=(mag0Min1[1::2]/2)**2
A=np.vstack([invN2**2,invN2,np.ones(len(invN2))]).T
p2=np.linalg.lstsq(A,mag0Min2)[0]
yQMC=p2[0]*x**2+p2[1]*x+p2[2]
yQMC=np.sqrt(yQMC)
print("mag0scaledQMC={0}".format(np.sqrt(p2[2])))
print(p2)
print(np.sqrt(p2[2])-0.3070)

mag0Min2=(mag0Min1[1::2]/2)
A=np.vstack([invN2**4,invN2**2,np.ones(len(invN2))]).T
p2=np.linalg.lstsq(A,mag0Min2)[0]
yCCM=p2[0]*x**4+p2[1]*x**2+p2[2]
print("mag0scaledCCM={0}".format(p2[2]))
print(p2)
print(p2[2]-0.3070)

ax1.plot(invN1,(mag0Min1/2),marker="o",markersize=myMarkersize,color="red",linestyle="None",label="arith. (Min.)")
ax1.plot(x,yQMC,color="red",linestyle="solid",linewidth=myLinewidth,label="Skal. arith. (Min.)")

ax3.plot(invN1,(mag0Min1/2),marker="o",markersize=myMarkersize,color="red",linestyle="None",label="arith. (Min.)")
ax3.plot(x,yCCM,color="red",linestyle="solid",linewidth=myLinewidth,label="Skal. arith. (Min.)")

### square expansion ###
print("\nminimum square expansion:")
invN1=np.array([2,3,4,5])
invN1=1/invN1
mag0Min1=np.array([mag0_squareAboutMin[0][1][27],mag0_squareAboutMin[1][1][39],mag0_squareAboutMin[2][1][25],mag0_squareAboutMin[3][1][24]])

print("mag0Min1={0}".format(mag0Min1/2))

invN2=invN1[1::2]
mag0Min2=(mag0Min1[1::2]/2)**2
A=np.vstack([invN2,np.ones(len(invN2))]).T
p2=np.linalg.lstsq(A,mag0Min2)[0]
yQMC=p2[0]*x+p2[1]
yQMC=np.sqrt(yQMC)
print("mag0scaledQMC={0}".format(np.sqrt(p2[1])))
print(p2)
print(np.sqrt(p2[1])-0.3070)

mag0Min2=(mag0Min1[1::2]/2)
A=np.vstack([invN2**2,np.ones(len(invN2))]).T
p2=np.linalg.lstsq(A,mag0Min2)[0]
yCCM=p2[0]*x**2+p2[1]
print("mag0scaledCCM={0}".format(p2[1]))
print(p2[1]-0.3070)

ax1.plot(invN1,(mag0Min1/2),marker="o",markersize=myMarkersize,color="green",linestyle="None",label="Quad. (Min.)")
ax1.plot(x,yQMC,color="green",linestyle="solid",linewidth=myLinewidth,label="Skal. Quad. (Min.)")

ax3.plot(invN1,(mag0Min1/2),marker="o",markersize=myMarkersize,color="green",linestyle="None",label="Quad. (Min.)")
ax3.plot(x,yCCM,color="green",linestyle="solid",linewidth=myLinewidth,label="Skal. Quad. (Min.)")

ax1.plot([0],[0.3070],marker="d",markersize=myMarkersize,color="black",linestyle="None",label="QMC",clip_on=False)
ax3.plot([0],[0.3070],marker="d",markersize=myMarkersize,color="black",linestyle="None",label="QMC",clip_on=False)

ax1.set_xlim([0.0,0.5])
ax1.set_ylim([0.0,0.5])
ax1.text(myTextOffset/4,0.5,"(a)",fontsize=10)
ax1.set_xlabel("$1/l$")
ax1.set_ylabel("$m_0$")

ax3.set_xlim([0.0,0.5])
ax3.set_ylim([0.0,0.5])
ax3.text(myTextOffset/4,0.5,"(b)",fontsize=10)
ax3.set_xlabel("$1/l$")
ax3.set_ylabel("$m_0$")

ax1.text(0.02,0.1,"Skal. (i)",fontsize=10)
ax3.text(0.02,0.1,"Skal. (ii)",fontsize=10)

lgd=ax1.legend(loc="upper left",bbox_to_anchor=(1.01, 1.02),ncol=1,fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)

plt.savefig("NLCE_squareOneHalf_mag_scaling_da.pdf")
plt.clf()

