import matplotlib.pyplot as plt
import numpy as np
from scipy.optimize import curve_fit

myFontsize=8.0
myLinewidth=0.6
myMarkersize=2.5
myMarkersizeBig=4.0
myFigsize_x=4.15
myFigsize_y=3.1125*2.2
myTextOffset=-0.4
plt.rc("text",usetex=True)
plt.rc("font",family="serif")
plt.rc("font",serif="Computer Modern Roman")
plt.rc("font",size=myFontsize)
plt.rc("axes",linewidth=myLinewidth)

lambdaValueList=[0.2,0.4,0.6,0.8,0.85,0.9,0.95,1]

m0BareList=np.zeros(len(lambdaValueList))

e0ScaledQMCList=np.zeros(len(lambdaValueList))
mag0ScaledQMCList=np.zeros(len(lambdaValueList))
e0ScaledCCMList=np.zeros(len(lambdaValueList))
mag0ScaledCCMList=np.zeros(len(lambdaValueList))

e0FixScaledQMCList=np.zeros(len(lambdaValueList))
mag0FixScaledQMCList=np.zeros(len(lambdaValueList))
e0FixScaledCCMList=np.zeros(len(lambdaValueList))
mag0FixScaledCCMList=np.zeros(len(lambdaValueList))

offset=5

index=0
for lambdaValue in lambdaValueList:
	fig, (ax1, ax3) = plt.subplots(2,figsize=(myFigsize_x, myFigsize_y))
	
	e0=[]
	mag0=[]
	e0Fix=np.zeros(4)
	mag0Fix=np.zeros(4)
	markerList=["o","s","d","^","v"]
	for order in np.arange(2,6):
		e0temp=np.loadtxt("lambda{1}/e0_order{0}_lambda{1}.txt".format(order,lambdaValue),unpack=True)
		e0.append(e0temp)
		ax1.plot(e0temp[0],e0temp[1],label="Ord. ${0}$".format(order),marker=markerList[(order-2)//5],markersize=myMarkersize,linewidth=myLinewidth)
		mag0temp=np.loadtxt("lambda{1}/mag0_order{0}_lambda{1}.txt".format(order,lambdaValue),unpack=True)
		ax3.plot(mag0temp[0],mag0temp[1]/2,label="Ord. ${0}$".format(order),marker=markerList[(order-2)//5],markersize=myMarkersize,linewidth=myLinewidth)
		mag0.append(mag0temp)
		if(index<7):
			e0Temp=np.loadtxt("selfConsistentResults/lambda{1}_order{0}/e0_order{0}.txt".format(order,lambdaValue),unpack=True)
			e0Fix[order-2]=e0Temp[1][-1]
			mag0Temp=np.loadtxt("selfConsistentResults/lambda{1}_order{0}/mag0_order{0}.txt".format(order,lambdaValue),unpack=True)
			mag0Fix[order-2]=mag0Temp[1][-1]
	if(index==7):
		e0Fix=np.array([-0.67418,-0.664078,-0.668375,-0.668479])
		mag0Fix=np.array([0.740645,0.751678,0.706889,0.697637])

	#plot series result
	x=lambdaValue
	e0Series=-1/2-1/6*x**2+1/1080*x**4-3587/2268000*x**6-660294389/800150400000*x**8-156875294970593832/503046234915840000000*x**10-0.000241942079720*x**12-0.000151122678477*x**14
	mag0Series=1/2-1/9*x**2-0.0177777777778*x**4-0.00947129349682*x**6-0.00744291529381*x**8-0.00437691024484*x**10-0.00360570635434*x**12-0.00280100515146*x**14
	ax1.plot([0.0,1.0],np.ones(2)*e0Series,color="black",label="SE")
	ax3.plot([0.0,1.0],np.ones(2)*mag0Series,color="black",label="SE")

	ax1LegLoc="upper right"
	ax3LegLoc="upper right"
	ax2LegLoc="lower left"
	ax4LegLoc="lower left"
	if(index==0): #0.2
		ax1.set_ylim([-0.5072,-0.5064])
		ax1LegLoc="lower left"
		ax3.set_ylim([0.495,0.496])
	if(index==1): #0.4
		ax1.set_ylim([-0.529,-0.525])
		ax3.set_ylim([0.478,0.485])
	if(index==2): #0.6
		ax1.set_ylim([-0.565,-0.558])
		ax1LegLoc="lower left"
		ax3.set_ylim([0.45,0.46])
		ax3LegLoc="lower left"
	if(index==4): #0.85
		ax1.set_ylim([-0.63,-0.61])
		ax3.set_ylim([0.39,0.42])
		ax3LegLoc="lower right"
		ax4LegLoc="upper left"
	if(index==3): #0.8
		ax1.set_ylim([-0.62,-0.60])
		ax1LegLoc="lower right"
		ax3.set_ylim([0.405,0.425])
		ax3LegLoc="lower right"
		ax4LegLoc="upper left"
	if(index==6): #0.95
		ax1.set_ylim([-0.665,-0.645])
		ax1LegLoc="lower right"
		ax3.set_ylim([0.35,0.40])
		ax3LegLoc="lower right"
		ax4LegLoc="upper left"
	if(index==5): #0.9
		ax1.set_ylim([-0.65,-0.63])
		ax1LegLoc="lower right"
		ax3.set_ylim([0.38,0.42])
		ax4LegLoc="upper left"
	if(index==7): #1.0
		ax1.set_ylim([-0.68,-0.66])
		ax1LegLoc="lower right"
		ax3.set_ylim([0.34,0.41])
		ax2LegLoc="upper left"
		ax4LegLoc="upper left"


	ax1.text(myTextOffset/2*0.4+0.1,ax1.get_ylim()[1],"(a)",fontsize=10)
	ax1.set_xlim([0.1,0.5])
	ax1.set_xlabel("$K/J$")
	ax1.set_ylabel("$e_0/J$")
	ax1.get_yaxis().get_major_formatter().set_useOffset(False)
	lgd=ax1.legend(loc=ax1LegLoc,ncol=1,fontsize=myFontsize,fancybox=True)
	lgd.get_frame().set_linewidth(myLinewidth)

	ax3.text(myTextOffset/2*0.4+0.1,ax3.get_ylim()[1],"(b)",fontsize=10)
	ax3.set_xlim([0.1,0.5])
	ax3.set_xlabel("$K/J$")
	ax3.set_ylabel("$m_0$")
	ax3.get_yaxis().get_major_formatter().set_useOffset(False)
	lgd=ax3.legend(loc=ax3LegLoc,ncol=1,fontsize=myFontsize,fancybox=True)
	lgd.get_frame().set_linewidth(myLinewidth)

	plt.savefig("NLCE_squareOneHalf_XXZ_lambda{0}_gse_mag_da.pdf".format(lambdaValue))
	plt.clf()
	#################################
	fig, (ax2, ax4) = plt.subplots(2,figsize=(myFigsize_x, myFigsize_y))

	# save bare value
	m0BareList[index]=mag0[5-2][1][offset+e0[5-2][1][offset:].argmin()]

	### scale minimal values ###
	invN1=[]
	e0Min1=[]
	invN1mag=[]
	mag0Min1=[]
	for order in np.arange(2,6):
		invN1.append(order)
		e0Min1.append(min(e0[order-2][1][offset:]))
		invN1mag.append(order)
		mag0Min1.append(mag0[order-2][1][offset+e0[order-2][1][offset:].argmin()])
	invN1=np.array(invN1)
	invN1=1/invN1
	invN1mag=np.array(invN1mag)
	invN1mag=1/invN1mag
	mag0Min1=np.array(mag0Min1)

	#e0 QMC scaling
	x=np.arange(0,invN1[0]+0.0001,0.0001)
	invN2=invN1[-3::2]**3
	e0Min2=e0Min1[-3::2]
	p2=np.polyfit(invN2,e0Min2,1)
	y2QMC=p2[0]*x**3+p2[1]
	e0ScaledQMCList[index]=p2[1]
	#e0 CCM scaling
	invN2=invN1[-3::2]**4
	e0Min2=e0Min1[-3::2]
	p2=np.polyfit(invN2,e0Min2,1)
	y2CCM=p2[0]*x**4+p2[1]
	e0ScaledCCMList[index]=p2[1]
	
    #m0 QMC scaling
	xmag=np.arange(0,invN1mag[0]+0.0001,0.0001)
	invN2mag=invN1mag[-3::2]
	mag0Min2=(mag0Min1[-3::2]/2)**2
	p2mag=np.polyfit(invN2mag,mag0Min2,1)
	y2magQMC=p2mag[0]*xmag+p2mag[1]
	y2magQMC=np.sqrt(y2magQMC)
	mag0ScaledQMCList[index]=np.sqrt(p2mag[1])
    #m0 CCM scaling
	invN2mag=invN1mag[-3::2]
	mag0Min2=(mag0Min1[-3::2]/2)
	p2mag=np.polyfit(invN2mag**2,mag0Min2,1)
	y2magCCM=p2mag[0]*xmag**2+p2mag[1]
	mag0ScaledCCMList[index]=p2mag[1]
    
	print("lambda={0}: e0scaledQMC={1} e0scaledCCM={2} mag0ScaledQMC={3} mag0ScaledCCM={4}".format(lambdaValue,e0ScaledQMCList[index],e0ScaledCCMList[index],mag0ScaledQMCList[index],mag0ScaledCCMList[index]))


	### scale fixpoint values ###
	#e0 QMC scaling
	x=np.arange(0,invN1[0]+0.0001,0.0001)
	invN2=invN1[-3::2]**3
	e0Min2=e0Fix[-3::2]
	p2=np.polyfit(invN2,e0Min2,1)
	y2FixQMC=p2[0]*x**3+p2[1]
	e0FixScaledQMCList[index]=p2[1]
	#e0 CCM scaling
	invN2=invN1[-3::2]**4
	e0Min2=e0Fix[-3::2]
	p2=np.polyfit(invN2,e0Min2,1)
	y2FixCCM=p2[0]*x**4+p2[1]
	e0FixScaledCCMList[index]=p2[1]
	
    #m0 QMC scaling
	xmag=np.arange(0,invN1mag[0]+0.0001,0.0001)
	invN2mag=invN1mag[-3::2]
	mag0Min2=(mag0Fix[-3::2]/2)**2
	p2mag=np.polyfit(invN2mag,mag0Min2,1)
	y2magFixQMC=p2mag[0]*xmag+p2mag[1]
	y2magFixQMC=np.sqrt(y2magFixQMC)
	mag0FixScaledQMCList[index]=np.sqrt(p2mag[1])
    #m0 CCM scaling
	invN2mag=invN1mag[-3::2]
	mag0Min2=(mag0Fix[-3::2]/2)
	p2mag=np.polyfit(invN2mag**2,mag0Min2,1)
	y2magFixCCM=p2mag[0]*xmag**2+p2mag[1]
	mag0FixScaledCCMList[index]=p2mag[1]


	ax2.plot(invN1,e0Fix,marker="s",markersize=myMarkersizeBig,color="red",linestyle="None",label="Fix.")
	ax2.plot(x,y2FixQMC,color="red",linestyle="solid",linewidth=myLinewidth,label="Skal. (i)")
	ax2.plot(x,y2FixCCM,color="red",linestyle="dashed",linewidth=myLinewidth,label="Skal. (ii)")
	ax2.plot(invN1,e0Min1,marker="o",markersize=myMarkersizeBig,color="cyan",linestyle="None",label="Min.")
	ax2.plot(x,y2QMC,color="cyan",linestyle="solid",linewidth=myLinewidth,label="Skal. (i)")
	ax2.plot(x,y2CCM,color="cyan",linestyle="dashed",linewidth=myLinewidth,label="Skal. (ii)")
	ax2.plot([0],e0Series,marker="d",markersize=myMarkersizeBig,linestyle="None",clip_on=False,color="black",label="SE")
	ax2.set_xlabel(r"$1/l$")
	if(index==3):
		ax2.set_ylim([-0.62,-0.59])
	ax2.set_ylabel("$e_0/J$")
	ax2.set_xlim([0,0.5001])
	ax2.text(myTextOffset/2*0.5,ax2.get_ylim()[1],"(a)",fontsize=10)
	ax2.get_yaxis().get_major_formatter().set_useOffset(False)
	lgd=ax2.legend(loc=ax2LegLoc,ncol=2,fontsize=myFontsize,fancybox=True)
	lgd.get_frame().set_linewidth(myLinewidth)
	
	ax4.plot(invN1mag,mag0Fix/2,marker="s",markersize=myMarkersizeBig,color="red",linestyle="None",label="Fix.")
	ax4.plot(xmag,y2magFixQMC,color="red",linestyle="solid",linewidth=myLinewidth,label="Skal. (i)")
	ax4.plot(xmag,y2magFixCCM,color="red",linestyle="dashed",linewidth=myLinewidth,label="Skal. (ii)")
	ax4.plot(invN1mag,np.array(mag0Min1)/2,marker="o",markersize=myMarkersizeBig,color="cyan",linestyle="None",label="Min.")
	ax4.plot(xmag,y2magQMC,color="cyan",linestyle="solid",linewidth=myLinewidth,label="Skal. (i)")
	ax4.plot(xmag,y2magCCM,color="cyan",linestyle="dashed",linewidth=myLinewidth,label="Skal. (ii)")
	ax4.plot([0],mag0Series,marker="d",markersize=myMarkersizeBig,linestyle="None",clip_on=False,color="black",label="SE")
	ax4.set_xlabel(r"$1/l$")
	ax4.set_ylabel("$m_0$")
	ax4.set_xlim([0,0.5001])
	if(index==0):
		ax4.set_ylim([0.4951,0.4956])
	#ax4.set_ylim([0,0.5])
	ax4.text(myTextOffset/2*0.5,ax4.get_ylim()[1],"(b)",fontsize=10)
	ax4.get_yaxis().get_major_formatter().set_useOffset(False)
	lgd=ax4.legend(loc=ax4LegLoc,ncol=2,fontsize=myFontsize,fancybox=True)
	lgd.get_frame().set_linewidth(myLinewidth)
	
	plt.savefig("NLCE_squareOneHalf_XXZ_lambda{0}_gse_mag_scaling_da.pdf".format(lambdaValue))
	plt.clf()

	index=index+1

#plot complete lambda-axis
f, (ax1, ax2) = plt.subplots(2, sharex=False, sharey=False,figsize=(myFigsize_x, myFigsize_y)) #share x- and y-axis

ax1.plot(lambdaValueList,e0ScaledQMCList,marker="s",markersize=myMarkersizeBig,color="cyan",linestyle="None",label="Min. Skal. (i)",zorder=2)
ax1.plot(lambdaValueList,e0ScaledCCMList,marker="^",markersize=myMarkersizeBig,color="cyan",linestyle="None",label="Min. Skal. (ii)",zorder=4)
ax1.plot(lambdaValueList,e0FixScaledQMCList,marker="s",markersize=myMarkersizeBig,color="red",linestyle="None",label="Fix. Skal. (i)",zorder=3)
ax1.plot(lambdaValueList,e0FixScaledCCMList,marker="^",markersize=myMarkersizeBig,color="red",linestyle="None",label="Fix. Skal. (ii)",zorder=5)
x=np.arange(0,1.001,0.01)
e0Series=-1/2-1/6*x**2+1/1080*x**4-3587/2268000*x**6-660294389/800150400000*x**8-156875294970593832/503046234915840000000*x**10-0.000241942079720*x**12-0.000151122678477*x**14
ax1.plot(x,e0Series,color="black",label="SE Ord. $14$",zorder=1)
ax1.plot([1],[-0.669437],marker="d",markersize=myMarkersizeBig,color="black",linestyle="None",clip_on=False,label="QMC",zorder=10)
ax1.set_xlabel("$\lambda$")
ax1.set_ylabel("$e_0/J$")
ax1.set_ylim([-0.68,-0.49])
ax1.text(myTextOffset/2,-0.49,"(a)",fontsize=10)
lgd=ax1.legend(loc="lower left",ncol=1, fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)

ax2.plot(lambdaValueList,m0BareList/2,marker="o",markersize=myMarkersizeBig,color="blue",linestyle="None",label="Min. Ord. $5$",zorder=3) #bare order 5 results
ax2.plot(lambdaValueList,mag0ScaledQMCList,marker="s",markersize=myMarkersizeBig,color="cyan",linestyle="None",label="Min. Skal. (i)",zorder=2)
ax2.plot(lambdaValueList,mag0ScaledCCMList,marker="^",markersize=myMarkersizeBig,color="cyan",linestyle="None",label="Min. Skal. (ii)",zorder=4)
ax2.plot(lambdaValueList,mag0FixScaledQMCList,marker="s",markersize=myMarkersizeBig,color="red",linestyle="None",label="Fix. Skal. (i)",zorder=3)
ax2.plot(lambdaValueList,mag0FixScaledCCMList,marker="^",markersize=myMarkersizeBig,color="red",linestyle="None",label="Fix. Skal. (ii)",zorder=5)
x=np.arange(0,1.001,0.01)
mag0Series=1/2-1/9*x**2-0.0177777777778*x**4-0.00947129349682*x**6-0.00744291529381*x**8-0.00437691024484*x**10-0.00360570635434*x**12-0.00280100515146*x**14
ax2.plot(x,mag0Series,color="black",label="SE Ord. $14$",zorder=1)
ax2.plot([1],[0.3070],marker="d",markersize=myMarkersizeBig,color="black",linestyle="None",clip_on=False,label="QMC",zorder=10)
ax2.set_ylabel("$m_0$")
ax2.set_ylim([0,0.52])
ax2.text(myTextOffset/2,0.52,"(b)",fontsize=10)
lgd=ax2.legend(loc="lower left",ncol=1, fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)


plt.xlabel("$\lambda$")
plt.savefig("NLCE_squareOneHalf_XXZ_da.pdf")
plt.clf()

