import matplotlib.pyplot as plt
import numpy as np

myFontsize=8.0
myLinewidth=0.6
myMarkersize=2.5
myMarkersizeBig=4.0
myFigsize_x=4.15
myFigsize_y=3.1125
myTextOffset=-0.37
plt.rc("text",usetex=True)
plt.rc("font",family="serif")
plt.rc("font",serif="Computer Modern Roman")
plt.rc("font",size=myFontsize)
plt.rc("axes",linewidth=myLinewidth)


### GROUND-STATE ENERGY ###
f, (ax3) = plt.subplots(1, sharex=False, sharey=False,figsize=(myFigsize_x, myFigsize_y)) #share x- and y-axis
markerList=["o","s","d","^","v"]
colorList=["blue","green","red","cyan","magenta","orange","black"]

### arithmetic expansion ###
e0_arithmetic=[]
e0_arithmeticAboutMin=[]
colorIndex=0
for order in np.arange(1,9):
	e0temp=np.loadtxt("results_triangularOneHalf_arithmeticExpansion_order8/e0_order{0}.txt".format(order),unpack=True)
	e0_arithmetic.append(e0temp)
	ax3.plot(e0temp[0][:2],e0temp[1][:2],label="Ord. ${0}$".format(order),marker=markerList[(order-1)//5],markersize=myMarkersize,linewidth=myLinewidth,color=colorList[colorIndex%7])
	ax3.plot(e0temp[0][5:],e0temp[1][5:],marker=markerList[(order-1)//5],markersize=myMarkersize,linewidth=myLinewidth,color=colorList[colorIndex%7])
	e0temp=np.loadtxt("results_triangularOneHalf_arithmeticExpansion_order8/e0_order{0}_aboutMin.txt".format(order),unpack=True)
	e0_arithmeticAboutMin.append(e0temp)
	ax3.plot(e0temp[0],e0temp[1],marker=markerList[(order-1)//5],markersize=myMarkersize,linewidth=myLinewidth,color=colorList[colorIndex%7])
	colorIndex=colorIndex+1

invNFix=np.array([1,2,3,4,6,8])
e0_arithmeticFix=np.zeros(len(invNFix))
tempIndex=0
for order in invNFix:
	e0temp=np.loadtxt("results_triangularOneHalf_arithmeticExpansion_order8_selfConsistent/order{0}/e0_order{0}.txt".format(order),unpack=True)
	e0_arithmeticFix[tempIndex]=e0temp[1][-1]
	tempIndex=tempIndex+1
invNFix=2/(invNFix+2)

ax3.plot(e0_arithmetic[0][0],-0.5458*np.ones(len(e0_arithmetic[0][0])),label="GFQMC",color="black")
ax3.plot(e0_arithmetic[0][0],-0.5502*np.ones(len(e0_arithmetic[0][0])),label="SE",color="black",linestyle='dashed')
lgd=ax3.legend(loc="upper right",ncol=1,fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)
ax3.set_ylim([-0.6,-0.35])
plt.savefig("NLCE_triangularOneHalf_gse_arithmeticExpansion_da.pdf")
plt.clf()

### square expansion ###
f, (ax4) = plt.subplots(1, sharex=False, sharey=False,figsize=(myFigsize_x, myFigsize_y)) #share x- and y-axis
e0_square=[]
e0_squareAboutMin=[]
e0_squareFix=np.zeros(4)
colorIndex=0
for order in np.arange(2,6):
	e0temp=np.loadtxt("results_triangularOneHalf_squareExpansion_order5/e0_order{0}.txt".format(order),unpack=True)
	e0_square.append(e0temp)
	ax4.plot(e0temp[0][:2],e0temp[1][:2],label="Ord. ${0}$".format(order),marker="o",markersize=myMarkersize,linewidth=myLinewidth,color=colorList[colorIndex])
	ax4.plot(e0temp[0][5:],e0temp[1][5:],marker="o",markersize=myMarkersize,linewidth=myLinewidth,color=colorList[colorIndex])
	e0temp=np.loadtxt("results_triangularOneHalf_squareExpansion_order5/e0_order{0}_aboutMin.txt".format(order),unpack=True)
	e0_squareAboutMin.append(e0temp)
	ax4.plot(e0temp[0],e0temp[1],marker="o",markersize=myMarkersize,linewidth=myLinewidth,color=colorList[colorIndex])
	colorIndex=colorIndex+1
	e0temp=np.loadtxt("results_triangularOneHalf_squareExpansion_order5_selfConsistent/order{0}/e0_order{0}.txt".format(order),unpack=True)
	e0_squareFix[order-2]=e0temp[1][-1]

ax4.plot(e0_square[0][0],-0.5458*np.ones(len(e0_square[0][0])),label="GFQMC",color="black")
ax4.plot(e0_square[0][0],-0.5502*np.ones(len(e0_square[0][0])),label="SE",color="black",linestyle='dashed')
lgd=ax4.legend(loc="upper right",ncol=1,fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)
ax4.set_ylim([-0.56,-0.44])

ax3.set_xlabel("$K/J$")
ax4.set_xlabel("$K/J$")
ax3.set_ylabel("$e_0/J$")
ax4.set_ylabel("$e_0/J$")

plt.savefig("NLCE_triangularOneHalf_gse_squareExpansion_da.pdf")
plt.clf()
######################################

f, (ax3_inset, ax4_inset) = plt.subplots(2, sharex=False, sharey=False,figsize=(myFigsize_x, myFigsize_y)) #share x- and y-axis


print("\nminimum arithmetic expansion:")
invN1=np.array([2,4,6,8])
invN1=2/(invN1+2)
e0Min1=[min(e0_arithmeticAboutMin[1][1]),min(e0_arithmeticAboutMin[3][1]),min(e0_arithmeticAboutMin[5][1]),min(e0_arithmeticAboutMin[7][1])]
print("order2: {0}".format(e0_arithmeticAboutMin[1][0][e0_arithmeticAboutMin[1][1].argmin()]))
print("order4: {0}".format(e0_arithmeticAboutMin[3][0][e0_arithmeticAboutMin[3][1].argmin()]))
print("order6: {0}".format(e0_arithmeticAboutMin[5][0][e0_arithmeticAboutMin[5][1].argmin()]))
print("order8: {0}".format(e0_arithmeticAboutMin[7][0][e0_arithmeticAboutMin[7][1].argmin()]))

print("e0Min1={0}".format(e0Min1))

invN2=invN1[1::]
e0Min2=e0Min1[1::]
x=np.arange(0,invN2[0]+0.0001,0.001)

# minimum QMC scaling
A=np.vstack([invN2**4,invN2**3,np.ones(len(invN2))]).T
p2=np.linalg.lstsq(A,e0Min2)[0]
yQMC=p2[0]*x**4+p2[1]*x**3+p2[2]
print("e0arithmeticMinQMC={0}".format(p2[2]))
print(p2[2]+0.5502)

# minimum CCM scaling
A=np.vstack([invN2**8,invN2**4,np.ones(len(invN2))]).T
p2=np.linalg.lstsq(A,e0Min2)[0]
yCCM=p2[0]*x**8+p2[1]*x**4+p2[2]
print("e0arithmeticMinCCM={0}".format(p2[2]))
print(p2[2]+0.5502)

print("\nfixpoint arithmetic expansion:")
e0Min2=e0_arithmeticFix[3::]
# fixpoint QMC scaling
A=np.vstack([invN2**4,invN2**3,np.ones(len(invN2))]).T
p2=np.linalg.lstsq(A,e0Min2)[0]
yFixQMC=p2[0]*x**4+p2[1]*x**3+p2[2]
print("e0arithmeticFixQMC={0}".format(p2[2]))
print(p2[2]+0.5502)

# minimum CCM scaling
A=np.vstack([invN2**8,invN2**4,np.ones(len(invN2))]).T
p2=np.linalg.lstsq(A,e0Min2)[0]
yFixCCM=p2[0]*x**8+p2[1]*x**4+p2[2]
print("e0arithmeticFixCCM={0}".format(p2[2]))
print(p2[2]+0.5502)

ax3_inset.plot(invNFix,e0_arithmeticFix,marker="s",markersize=myMarkersizeBig,color="red",linestyle="None",label="Fix.")
ax3_inset.plot(x,yFixQMC,color="red",linestyle="solid",linewidth=myLinewidth,label="Skal. (i)")
ax3_inset.plot(x,yFixCCM,color="red",linestyle="dashed",linewidth=myLinewidth,label="Skal. (ii)")
ax3_inset.plot(invN1,e0Min1,marker="o",markersize=myMarkersizeBig,color="cyan",linestyle="None",label="Min.")
ax3_inset.plot(x,yQMC,color="cyan",linestyle="solid",linewidth=myLinewidth,label="Skal. (i)")
ax3_inset.plot(x,yCCM,color="cyan",linestyle="dashed",linewidth=myLinewidth,label="Skal. (ii)")
ax3_inset.plot([0],[-0.5458],linestyle="None",marker="d",markersize=myMarkersizeBig,label="GFQMC",color="black",clip_on=False)
ax3_inset.plot([0],[-0.5502],linestyle="None",marker="*",markersize=myMarkersizeBig,label="SE",color="black",clip_on=False)
lgd=ax3_inset.legend(loc="upper left",ncol=2,fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)
ax3_inset.set_xlabel(r"$1/l$")
ax3_inset.set_ylabel("$e_0/J$")
ax3_inset.set_ylim([-0.56,-0.52])
ax3_inset.text(myTextOffset/2*0.35,-0.52,"(a)",fontsize=10)
ax3_inset.set_yticks(np.arange(-0.56,-0.52+0.001,0.01))
ax3_inset.set_xlim([0,0.35])


# scaling inset square
print("\nminimum square expansion:")
invN1=np.array([2,3,4,5])
invN1=1/invN1
e0Min1=[min(e0_squareAboutMin[0][1]),min(e0_squareAboutMin[1][1]),min(e0_squareAboutMin[2][1]),min(e0_squareAboutMin[3][1])]

invN2=invN1[1::]
e0Min2=e0Min1[1::]

x=np.arange(0,invN1[0]+0.0001,0.001)

# minimum QMC
A=np.vstack([invN2**4,invN2**3,np.ones(len(invN2))]).T
p2=np.linalg.lstsq(A,e0Min2)[0]
yQMC=p2[0]*x**4+p2[1]*x**3+p2[2]
print("e0squareMinQMC={0}".format(p2[2]))
print(p2[2]+0.5502)

# minimum CCM
A=np.vstack([invN2**8,invN2**4,np.ones(len(invN2))]).T
p2=np.linalg.lstsq(A,e0Min2)[0]
yCCM=p2[0]*x**8+p2[1]*x**4+p2[2]
print("e0squareMinCCM={0}".format(p2[2]))
print(p2[2]+0.5502)


print("\nfixpoint square expansion:")
# fixpoint QMC
e0Min2=e0_squareFix[1::]
A=np.vstack([invN2**4,invN2**3,np.ones(len(invN2))]).T
p2=np.linalg.lstsq(A,e0Min2)[0]
yFixQMC=p2[0]*x**4+p2[1]*x**3+p2[2]
print("e0squareFixQMC={0}".format(p2[2]))
print(p2[2]+0.5502)

# fixpoint CCM
A=np.vstack([invN2**8,invN2**4,np.ones(len(invN2))]).T
p2=np.linalg.lstsq(A,e0Min2)[0]
yFixCCM=p2[0]*x**8+p2[1]*x**4+p2[2]
print("e0squareFixCCM={0}".format(p2[2]))
print(p2[2]+0.5502)


ax4_inset.plot(invN1,e0_squareFix,marker="s",markersize=myMarkersizeBig,color="red",linestyle="None",label="Fix.")
ax4_inset.plot(x,yFixQMC,color="red",linestyle="solid",linewidth=myLinewidth,label="Skal. (i)")
ax4_inset.plot(x,yFixCCM,color="red",linestyle="dashed",linewidth=myLinewidth,label="Skal. (ii)")
ax4_inset.plot(invN1,e0Min1,marker="o",markersize=myMarkersizeBig,color="cyan",linestyle="None",label="Min.")
ax4_inset.plot(x,yQMC,color="cyan",linestyle="solid",linewidth=myLinewidth,label="Skal. (i)")
ax4_inset.plot(x,yCCM,color="cyan",linestyle="dashed",linewidth=myLinewidth,label="Skal. (ii)")
ax4_inset.plot([0],[-0.5458],linestyle="None",marker="d",markersize=myMarkersizeBig,label="GFQMC",color="black",clip_on=False)
ax4_inset.plot([0],[-0.5502],linestyle="None",marker="*",markersize=myMarkersizeBig,label="SE",color="black",clip_on=False)
lgd=ax4_inset.legend(loc="upper left",ncol=2,fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)
ax4_inset.set_xlabel(r"$1/l$")
ax4_inset.set_ylabel("$e_0/J$")
ax4_inset.set_ylim([-0.56,-0.44])
ax4_inset.set_xlim([0,0.5001])
ax4_inset.text(myTextOffset/2*0.5,-0.44,"(b)",fontsize=10)

plt.savefig("NLCE_triangularOneHalf_gse_scaling_da.pdf")
plt.clf()

