import matplotlib.pyplot as plt
import numpy as np

myFontsize=8.0
myLinewidth=0.6
myMarkersize=2.5
myMarkersizeBig=4.0
myFigsize_x=4.15
myFigsize_y=3.1125*2.2
myTextOffset=-0.37
plt.rc("text",usetex=True)
plt.rc("font",family="serif")
plt.rc("font",serif="Computer Modern Roman")
plt.rc("font",size=myFontsize)
plt.rc("axes",linewidth=myLinewidth)

### GROUND-STATE ENERGY ###
f, (ax3, ax4) = plt.subplots(2, sharex=False, sharey=False,figsize=(myFigsize_x, myFigsize_y)) #share x- and y-axis
markerList=["o","s","d","^","v"]
colorList=["blue","green","red","cyan","magenta","orange","black"]

### arithmetic expansion ###
mag0_arithmetic=[]
mag0_arithmeticAboutMin=[]
colorIndex=0
for order in np.arange(1,9):
	mag0temp=np.loadtxt("results_triangularOneHalf_arithmeticExpansion_order8/mag0_order{0}.txt".format(order),unpack=True)
	mag0_arithmetic.append(mag0temp)
	ax3.plot(mag0temp[0][:2],mag0temp[1][:2]/2,label="Ord. ${0}$".format(order),marker=markerList[(order-1)//5],markersize=myMarkersize,linewidth=myLinewidth,color=colorList[colorIndex%7])
	ax3.plot(mag0temp[0][5:],mag0temp[1][5:]/2,marker=markerList[(order-1)//5],markersize=myMarkersize,linewidth=myLinewidth,color=colorList[colorIndex%7])
	mag0temp=np.loadtxt("results_triangularOneHalf_arithmeticExpansion_order8/mag0_order{0}_aboutMin.txt".format(order),unpack=True)
	mag0_arithmeticAboutMin.append(mag0temp)
	ax3.plot(mag0temp[0],mag0temp[1]/2,marker=markerList[(order-1)//5],markersize=myMarkersize,linewidth=myLinewidth,color=colorList[colorIndex%7])
	colorIndex=colorIndex+1

invNFix=np.array([1,2,3,4,6,8])
mag0_arithmeticFix=np.zeros(len(invNFix))
tempIndex=0
for order in invNFix:
	mag0temp=np.loadtxt("results_triangularOneHalf_arithmeticExpansion_order8_selfConsistent/order{0}/mag0_order{0}.txt".format(order),unpack=True)
	mag0_arithmeticFix[tempIndex]=mag0temp[1][-1]
	tempIndex=tempIndex+1
invNFix=2/(invNFix+2)

ax3.plot(mag0_arithmetic[0][0],0.205*np.ones(len(mag0_arithmetic[0][0])),label="GFQMC",color="black")
ax3.plot(mag0_arithmetic[0][0],0.19*np.ones(len(mag0_arithmetic[0][0])),label="SE",color="black",linestyle='dashed')
lgd=ax3.legend(loc="lower right",ncol=2,fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)
ax3.set_ylim([0.0,0.5])
ax3.text(myTextOffset,0.5,"(a)",fontsize=10)

### square expansion ###
mag0_square=[]
mag0_squareAboutMin=[]
mag0_squareFix=np.zeros(4)
colorIndex=0
for order in np.arange(2,6):
	mag0temp=np.loadtxt("results_triangularOneHalf_squareExpansion_order5/mag0_order{0}.txt".format(order),unpack=True)
	mag0_square.append(mag0temp)
	ax4.plot(mag0temp[0][:2],mag0temp[1][:2]/2,label="Ord. ${0}$".format(order),marker="o",markersize=myMarkersize,linewidth=myLinewidth,color=colorList[colorIndex])
	ax4.plot(mag0temp[0][3:],mag0temp[1][3:]/2,marker="o",markersize=myMarkersize,linewidth=myLinewidth,color=colorList[colorIndex])
	mag0temp=np.loadtxt("results_triangularOneHalf_squareExpansion_order5/mag0_order{0}_aboutMin.txt".format(order),unpack=True)
	mag0_squareAboutMin.append(mag0temp)
	ax4.plot(mag0temp[0],mag0temp[1]/2,marker="o",markersize=myMarkersize,linewidth=myLinewidth,color=colorList[colorIndex])
	colorIndex=colorIndex+1
	mag0temp=np.loadtxt("results_triangularOneHalf_squareExpansion_order5_selfConsistent/order{0}/mag0_order{0}.txt".format(order),unpack=True)
	mag0_squareFix[order-2]=mag0temp[1][-1]

ax4.plot(mag0_square[0][0],0.205*np.ones(len(mag0_square[0][0])),label="GFQMC",color="black")
ax4.plot(mag0_square[0][0],0.19*np.ones(len(mag0_square[0][0])),label="SE",color="black",linestyle='dashed')
lgd=ax4.legend(loc="lower right",ncol=2,fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)
ax4.set_ylim([0.0,0.5])
ax4.text(myTextOffset,0.5,"(b)",fontsize=10)

ax3.set_xlabel("$K/J$")
ax4.set_xlabel("$K/J$")
ax3.set_ylabel("$m_0$")
ax4.set_ylabel("$m_0$")
plt.savefig("NLCE_triangularOneHalf_mag_arithmeticSquare_da.pdf")
plt.clf()
###########################################

f, (ax3_inset, ax4_inset) = plt.subplots(2, sharex=False, sharey=False,figsize=(myFigsize_x, myFigsize_y)) #share x- and y-axis

# scaling inset arithmetic
print("\nminimum arithmetic expansion:")
invN1=np.array([2,4,6,8])
invN1=2/(invN1+2)
mag0Min1=np.array([mag0_arithmeticAboutMin[1][1][40],mag0_arithmeticAboutMin[3][1][24],mag0_arithmeticAboutMin[5][1][30],mag0_arithmeticAboutMin[7][1][32]])

print("mag0Min1={0}".format(mag0Min1))

x=np.arange(0,invN1[0]+0.0001,0.001)

# minimum linear
invN2=invN1[1::]
mag0Min2=(mag0Min1[1::]/2)
A=np.vstack([invN2,np.ones(len(invN2))]).T
p2=np.linalg.lstsq(A,mag0Min2)[0]
yLin=p2[0]*x+p2[1]
print("m0ScaledLin={0}".format(p2[1]))

invN2=invN1[1::]
mag0Min2=(mag0Min1[1::]/2)**2

# minimum QMC
A=np.vstack([invN2**2,invN2,np.ones(len(invN2))]).T
p2=np.linalg.lstsq(A,mag0Min2)[0]
yQMC=p2[0]*x**2+p2[1]*x+p2[2]
yQMC=np.sqrt(yQMC)
print("m0arithmeticMinQMC={0}".format(np.sqrt(p2[2])))
print(np.sqrt(p2[2])-0.19)

# minimum CCM
mag0Min2=(mag0Min1[1::]/2)
A=np.vstack([invN2**2,invN2,np.ones(len(invN2))]).T
p2=np.linalg.lstsq(A,mag0Min2)[0]
yCCM=p2[0]*x**2+p2[1]*x+p2[2]
print("m0arithmeticMinCCM={0}".format(p2[2]))
print(p2[2]-0.19)

# self-consistent
mag0Min2=(mag0_arithmeticFix[3::]/2)**2

# minimum QMC
A=np.vstack([invN2**2,invN2,np.ones(len(invN2))]).T
p2=np.linalg.lstsq(A,mag0Min2)[0]
yFixQMC=p2[0]*x**2+p2[1]*x+p2[2]
yFixQMC=np.sqrt(yFixQMC)
print("m0arithmeticFixQMC={0}".format(np.sqrt(p2[2])))
print(np.sqrt(p2[2])-0.19)

# minimum CCM
mag0Min2=(mag0_arithmeticFix[3::]/2)
A=np.vstack([invN2**2,invN2,np.ones(len(invN2))]).T
p2=np.linalg.lstsq(A,mag0Min2)[0]
yFixCCM=p2[0]*x**2+p2[1]*x+p2[2]
print("m0arithmeticFixCCM={0}".format(p2[2]))
print(p2[2]-0.19)


ax3_inset.plot(invNFix,mag0_arithmeticFix/2,marker="s",markersize=myMarkersizeBig,color="red",linestyle="None",label="Fix.")
ax3_inset.plot(x,yFixQMC,color="red",linestyle="solid",linewidth=myLinewidth,label="Skal. (i)")
ax3_inset.plot(x,yFixCCM,color="red",linestyle="dashed",linewidth=myLinewidth,label="Skal. (ii)")
ax3_inset.plot(invN1,mag0Min1/2,marker="o",markersize=myMarkersizeBig,color="cyan",linestyle="None",label="Min.")
ax3_inset.plot(x,yQMC,color="cyan",linestyle="solid",linewidth=myLinewidth,label="Skal. (i)")
ax3_inset.plot(x,yCCM,color="cyan",linestyle="dashed",linewidth=myLinewidth,label="Skal. (ii)")
ax3_inset.plot(x,yLin,color="cyan",linestyle="dashdot",linewidth=myLinewidth,label="Skal. (lin.)")
ax3_inset.plot([0],[0.205],linestyle="None",marker="d",markersize=myMarkersizeBig,label="GFQMC",color="black",clip_on=False)
ax3_inset.plot([0],[0.19],linestyle="None",marker="*",markersize=myMarkersizeBig,label="SE",color="black",clip_on=False)
lgd=ax3_inset.legend(loc="lower right",ncol=2,fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)
ax3_inset.set_xlabel(r"$1/\mathcal{L}$")
ax3_inset.set_ylabel(r"$m_0$")
ax3_inset.set_xlim([0,0.5001])
ax3_inset.set_ylim([0.0,0.50])
ax3_inset.text(myTextOffset/2*0.5,0.5,"(a)",fontsize=10)
ax3_inset.set_yticks(np.arange(0,0.501,0.1))


# scaling inset square
print("\nminimum square expansion:")
invN1=np.array([2,3,4,5])
invN1=1/invN1
mag0Min1=np.array([mag0_squareAboutMin[0][1][17],mag0_squareAboutMin[1][1][13],mag0_squareAboutMin[2][1][9],mag0_squareAboutMin[3][1][9]])
print("mag0Min1={0}".format(mag0Min1))

x=np.arange(0,invN1[0]+0.0001,0.001)
invN2=invN1[1::]

# minimum QMC
mag0Min2=(mag0Min1[1::]/2)**2
A=np.vstack([invN2**2,invN2,np.ones(len(invN2))]).T
p2=np.linalg.lstsq(A,mag0Min2)[0]
yQMC=p2[0]*x**2+p2[1]*x+p2[2]
yQMC=np.sqrt(yQMC)
print("mag0squareMinQMC={0}".format(np.sqrt(p2[2])))
print(np.sqrt(p2[2])-0.19)

# minimum CCM
mag0Min2=(mag0Min1[1::]/2)
A=np.vstack([invN2**4,invN2**2,np.ones(len(invN2))]).T
p2=np.linalg.lstsq(A,mag0Min2)[0]
yCCM=p2[0]*x**4+p2[1]*x**2+p2[2]
print("mag0squareMinCCM={0}".format(p2[2]))
print(p2[2]-0.19)

# fixpoint QMC
mag0Min2=(mag0_squareFix[1::]/2)**2
A=np.vstack([invN2**2,invN2,np.ones(len(invN2))]).T
p2=np.linalg.lstsq(A,mag0Min2)[0]
yFixQMC=p2[0]*x**2+p2[1]*x+p2[2]
yFixQMC=np.sqrt(yFixQMC)
print("mag0squareFixQMC={0}".format(np.sqrt(p2[2])))
print(np.sqrt(p2[2])-0.19)

# fixpoint CCM
mag0Min2=(mag0_squareFix[1::]/2)
A=np.vstack([invN2**4,invN2**2,np.ones(len(invN2))]).T
p2=np.linalg.lstsq(A,mag0Min2)[0]
yFixCCM=p2[0]*x**4+p2[1]*x**2+p2[2]
print("mag0squareFixCCM={0}".format(p2[2]))
print(p2[2]-0.19)

ax4_inset.plot(invN1,mag0_squareFix/2,marker="s",markersize=myMarkersizeBig,color="red",linestyle="None",label="Fix.")
ax4_inset.plot(x,yFixQMC,color="red",linestyle="solid",linewidth=myLinewidth,label="Skal. (i)")
ax4_inset.plot(x,yFixCCM,color="red",linestyle="dashed",linewidth=myLinewidth,label="Skal. (ii)")
ax4_inset.plot(invN1,mag0Min1/2,marker="o",markersize=myMarkersizeBig,color="cyan",linestyle="None",label="Min.")
ax4_inset.plot(x,yQMC,color="cyan",linestyle="solid",linewidth=myLinewidth,label="Skal. (i)")
ax4_inset.plot(x,yCCM,color="cyan",linestyle="dashed",linewidth=myLinewidth,label="Skal. (ii)")
ax4_inset.plot([0],[0.205],linestyle="None",marker="d",markersize=myMarkersizeBig,label="GFQMC",color="black",clip_on=False)
ax4_inset.plot([0],[0.19],linestyle="None",marker="*",markersize=myMarkersizeBig,label="SE",color="black",clip_on=False)
lgd=ax4_inset.legend(loc="lower right",ncol=2,fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)
ax4_inset.set_xlabel(r"$1/\mathcal{L}$")
ax4_inset.set_ylabel(r"$m_0$")
ax4_inset.set_xlim([0.0,0.5001])
ax4_inset.set_ylim([0.0,0.5])
ax4_inset.text(myTextOffset/2*0.5,0.5,"(b)",fontsize=10)

plt.savefig("NLCE_triangularOneHalf_mag_scaling_da.pdf")
plt.clf()

