import matplotlib.pyplot as plt
import numpy as np
import scipy as sp

myFontsize=8.0
myLinewidth=0.6
myMarkersize=2.5
myMarkersizeBig=4.0
myFigsize_x=4.15
myFigsize_y=3.1125*2.2
myTextOffset=-0.4
plt.rc("text",usetex=True)
plt.rc("font",family="serif")
plt.rc("font",serif="Computer Modern Roman")
plt.rc("font",size=myFontsize)
plt.rc("axes",linewidth=myLinewidth)

lambdaValueList=[0.2,0.4,0.6,0.8,0.85,0.9,0.95,1]
m0BareList=np.zeros(len(lambdaValueList))

e0ScaledQMCList=np.zeros(len(lambdaValueList))
e0ScaledCCMList=np.zeros(len(lambdaValueList))

e0FixScaledQMCList=np.zeros(len(lambdaValueList))
e0FixScaledCCMList=np.zeros(len(lambdaValueList))

offset=5

# load fits with bounds
mag0MinQMCFit=np.loadtxt("nonlinearFitWithBounds/minQMCFit.txt",unpack=True)
mag0ScaledQMCList=np.sqrt(mag0MinQMCFit[3])
mag0MinCCMFit=np.loadtxt("nonlinearFitWithBounds/minCCMFit.txt",unpack=True)
mag0ScaledCCMList=mag0MinCCMFit[3]
mag0FixQMCFit=np.loadtxt("nonlinearFitWithBounds/fixQMCFit.txt",unpack=True)
mag0FixScaledQMCList=np.sqrt(mag0FixQMCFit[3])
mag0FixCCMFit=np.loadtxt("nonlinearFitWithBounds/fixCCMFit.txt",unpack=True)
mag0FixScaledCCMList=mag0FixCCMFit[3]

markerList=["o","s","d","^","v"]

index=0
for lambdaValue in lambdaValueList:
	fig, (ax1,ax3)=plt.subplots(2,figsize=(myFigsize_x,myFigsize_y))
	
	e0=[]
	mag0=[]
	e0Fix=np.zeros(4)
	mag0Fix=np.zeros(4)
	for order in np.arange(2,6):
		e0temp=np.loadtxt("lambda{1}/e0_order{0}_lambda{1}.txt".format(order,lambdaValue),unpack=True)
		e0.append(e0temp)
		ax1.plot(e0temp[0],e0temp[1],label="Ord. ${0}$".format(order),markersize=myMarkersize,linewidth=myLinewidth,marker=markerList[(order-2)//5])
		mag0temp=np.loadtxt("lambda{1}/mag0_order{0}lambda{1}.txt".format(order,lambdaValue),unpack=True)
		mag0.append(mag0temp)
		ax3.plot(mag0temp[0],mag0temp[1]/2,label="Ord. ${0}$".format(order),markersize=myMarkersize,linewidth=myLinewidth,marker=markerList[(order-2)//5])
		e0Temp=np.loadtxt("selfConsistentResults/lambda{1}_order{0}/e0_order{0}.txt".format(order,lambdaValue),unpack=True)
		e0Fix[order-2]=e0Temp[1][-1]
		mag0Temp=np.loadtxt("selfConsistentResults/lambda{1}_order{0}/mag0_order{0}.txt".format(order,lambdaValue),unpack=True)
		mag0Fix[order-2]=mag0Temp[1][-1]

	#plot series result
	x=lambdaValue
	e0Series=-0.375-0.16875*x**2+0.03375*x**3-0.04433705357*x**4+0.020425863*x**5-0.02832908602*x**6+0.03153484699*x**7-0.04765982794*x**8+0.06850871690*x**9-0.1025445984*x**10+0.1565521577*x**11-0.2455267547*x**12+0.3935047914*x**13
	mag0Series=0.5-0.135*x**2+0.054*x**3-0.1363457908*x**4+0.08589755026*x**5-0.1657631567*x**6+0.2055368406*x**7-0.3691101414*x**8+0.5890651357*x**9-1.005494430*x**10+1.700641966*x**11-2.948749946*x**12+5.156611906*x**13
    
	ax1LegLoc="lower right"
	ax3LegLoc="lower right"
	ax1Col=1
	ax3Col=1
	
	if(index==0):
		ax1.set_ylim([-0.382,-0.378])
		ax3.set_ylim([0.494,0.499])
		ax1LegLoc="upper left"
		ax3LegLoc="upper left"
	if(index==1):
		ax1.set_ylim([-0.405,-0.385])
		ax3.set_ylim([0.475,0.5])
		ax1LegLoc="center right"
		ax3LegLoc="upper right"
		ax3Col=2
	if(index==2):
		ax1.set_ylim([-0.44,-0.38])
		ax3.set_ylim([0.44,0.5])
		ax1LegLoc="upper right"
		ax3LegLoc="upper right"
		ax3Col=2
	if(index==3):
		ax1.set_ylim([-0.49,-0.42])
		ax3.set_ylim([0.38,0.5])
		ax1LegLoc="center right"
		ax3LegLoc="upper center"
	if(index==4):
		ax1.set_ylim([-0.5,-0.42])
		ax3.set_ylim([0.35,0.5])
		ax1LegLoc="center right"
		ax3LegLoc="upper center"
	if(index==5):
		ax1.set_ylim([-0.52,-0.42])
		ax3.set_ylim([0.3,0.5])
		ax1LegLoc="center right"
		ax3LegLoc="upper center"
		ax3Col=2
	if(index==6):
		ax1.set_ylim([-0.54,-0.43])
		ax3.set_ylim([0.3,0.5])
		ax1LegLoc="center right"
		ax3LegLoc="upper center"
	if(index==7):
		ax1.set_ylim([-0.56,-0.44])
		ax3.set_ylim([0.25,0.5])
		ax1LegLoc="center right"
		ax3LegLoc="upper center"

	ax1.set_xlabel("$K/J$")
	ax1.set_ylabel("$e_0/J$")
	ax1.text(myTextOffset/2*0.5,ax1.get_ylim()[1],"(a)",fontsize=10)
	lgd=ax1.legend(loc=ax1LegLoc,ncol=ax1Col,fontsize=myFontsize,fancybox=True)
	lgd.get_frame().set_linewidth(myLinewidth)
	
	ax3.set_xlabel("$K/J$")
	ax3.set_ylabel("$m_0$")
	ax3.text(myTextOffset/2*0.5,ax3.get_ylim()[1],"(b)",fontsize=10)
	lgd=ax3.legend(loc=ax3LegLoc,ncol=ax3Col,fontsize=myFontsize,fancybox=True)
	lgd.get_frame().set_linewidth(myLinewidth)

	plt.savefig("NLCE_triangularOneHalf_XXZ_lambda{0}_gse_mag_da.pdf".format(lambdaValue))
	plt.clf()
	########################################################	

	fig, (ax2,ax3)=plt.subplots(2,figsize=(myFigsize_x,myFigsize_y))

	# save bare value
	m0BareList[index]=mag0[5-2][1][offset+e0[5-2][1][offset:].argmin()]

	# scale minimal values
	invN1=[]
	e0Min1=[]
	invN1mag=[]
	mag0Min1=[]
	for order in np.arange(2,6):
		invN1.append(order)
		e0Min1.append(min(e0[order-2][1][offset:]))
		invN1mag.append(order)
		mag0Min1.append(mag0[order-2][1][offset+e0[order-2][1][offset:].argmin()])
	invN1=np.array(invN1)
	invN1=1/invN1
	invN1mag=np.array(invN1mag)
	invN1mag=1/invN1mag
	mag0Min1=np.array(mag0Min1)

	x=np.arange(0,invN1[0]+0.0001,0.0001)
	#e0 QMC scaling
	invN2=invN1[1::]
	e0Min2=e0Min1[1::]
	A=np.vstack([invN2**4,invN2**3,np.ones(len(invN2))]).T
	p2=np.linalg.lstsq(A,e0Min2)[0]
	yQMC=p2[0]*x**4+p2[1]*x**3+p2[2]
	e0ScaledQMCList[index]=p2[2]
	#e0 CCM scaling
	invN2=invN1[1::]
	e0Min2=e0Min1[1::]
	A=np.vstack([invN2**8,invN2**4,np.ones(len(invN2))]).T
	p2=np.linalg.lstsq(A,e0Min2)[0]
	yCCM=p2[0]*x**8+p2[1]*x**4+p2[2]
	e0ScaledCCMList[index]=p2[2]

	if(index==7):
		#mag0 QMC scaling
		invN2mag=invN1mag[1::]
		mag0Min2=(mag0Min1[1::]/2)**2
		A=np.vstack([invN2**2,invN2,np.ones(len(invN2))]).T
		p2=np.linalg.lstsq(A,mag0Min2)[0]
		yMagQMC=p2[0]*x**2+p2[1]*x+p2[2]
		yMagQMC=np.sqrt(yMagQMC)
		mag0ScaledQMCList[index]=np.sqrt(p2[2])
		print("mag0MinQMC={0}".format(p2))
    	#mag0 CCM scaling
		invN2mag=invN1mag[1::]
		mag0Min2=(mag0Min1[1::]/2)
		A=np.vstack([invN2**4,invN2**2,np.ones(len(invN2))]).T
		p2=np.linalg.lstsq(A,mag0Min2)[0]
		yMagCCM=p2[0]*x**4+p2[1]*x**2+p2[2]
		mag0ScaledCCMList[index]=p2[2]
		print("mag0MinCCM={0}".format(p2))
	else:
		yMagQMC=np.sqrt(mag0MinQMCFit[1][index]*x**2+mag0MinQMCFit[2][index]*x+mag0MinQMCFit[3][index])
		yMagCCM=mag0MinCCMFit[1][index]*x**4+mag0MinCCMFit[2][index]*x**2+mag0MinCCMFit[3][index]


	print("lambda={0}: e0scaledQMC={1} e0scaledCCM={2} mag0ScaledQMC={3} mag0ScaledCCM={4}".format(lambdaValue,e0ScaledQMCList[index],e0ScaledCCMList[index],mag0ScaledQMCList[index],mag0ScaledCCMList[index]))
	print(mag0Min1)
	print(mag0Fix)


	### scale fixpoint values ###
	#e0 QMC scaling
	invN2=invN1[1::]
	e0Min2=e0Fix[1::]
	A=np.vstack([invN2**4,invN2**3,np.ones(len(invN2))]).T
	p2=np.linalg.lstsq(A,e0Min2)[0]
	yFixQMC=p2[0]*x**4+p2[1]*x**3+p2[2]
	e0FixScaledQMCList[index]=p2[2]
	#e0 CCM scaling
	invN2=invN1[1::]
	e0Min2=e0Fix[1::]
	A=np.vstack([invN2**8,invN2**4,np.ones(len(invN2))]).T
	p2=np.linalg.lstsq(A,e0Min2)[0]
	yFixCCM=p2[0]*x**8+p2[1]*x**4+p2[2]
	e0FixScaledCCMList[index]=p2[2]

	if(index==7):
		#mag0 QMC scaling
		invN2mag=invN1mag[1::]
		mag0Min2=(mag0Fix[1::]/2)**2
		A=np.vstack([invN2**2,invN2,np.ones(len(invN2))]).T
		p2=np.linalg.lstsq(A,mag0Min2)[0]
		yMagFixQMC=p2[0]*x**2+p2[1]*x+p2[2]
		yMagFixQMC=np.sqrt(yMagFixQMC)
		mag0FixScaledQMCList[index]=np.sqrt(p2[2])
		print("mag0FixQMC={0}".format(p2))
    	#mag0 CCM scaling
		invN2mag=invN1mag[1::]
		mag0Min2=(mag0Fix[1::]/2)
		A=np.vstack([invN2**4,invN2**2,np.ones(len(invN2))]).T
		p2=np.linalg.lstsq(A,mag0Min2)[0]
		yMagFixCCM=p2[0]*x**4+p2[1]*x**2+p2[2]
		mag0FixScaledCCMList[index]=p2[2]
		print("mag0FixCCM={0}".format(p2))
	else:
		yMagFixQMC=np.sqrt(mag0FixQMCFit[1][index]*x**2+mag0FixQMCFit[2][index]*x+mag0FixQMCFit[3][index])
		yMagFixCCM=mag0FixCCMFit[1][index]*x**4+mag0FixCCMFit[2][index]*x**2+mag0FixCCMFit[3][index]

	
	ax2LegLoc="upper left"
	ax3LegLoc="upper left"
	if(index==0): #0.2
		ax2.set_ylim([-0.382,-0.378])
		ax3.set_ylim([0.492,0.5])
	if(index==1): #0.4
		ax2.set_ylim([-0.405,-0.385])
		ax3.set_ylim([0.475,0.5])
	if(index==2): #0.6
		ax2.set_ylim([-0.435,-0.40])
		ax3.set_ylim([0.43,0.49])
	if(index==3): #0.8
		ax2.set_ylim([-0.49,-0.42])
		ax3.set_ylim([0.36,0.5])
	if(index==4): #0.85
		ax2.set_ylim([-0.5,-0.42])
		ax3.set_ylim([0.3,0.5])
	if(index==5): #0.9
		ax2.set_ylim([-0.52,-0.43])
		ax3.set_ylim([0.3,0.5])
	if(index==6): #0.95
		ax2.set_ylim([-0.54,-0.44])
		ax3.set_ylim([0.2,0.5])
	if(index==7): #1.0
		ax2.set_ylim([-0.6,-0.40])
		ax3.set_ylim([0.0,0.5])


	ax2.plot(invN1,e0Fix,marker="s",markersize=myMarkersizeBig,color="red",linestyle="None",label="Fix.")
	ax2.plot(x,yFixQMC,color="red",linestyle="solid",linewidth=myLinewidth,label="Skal. (i)")
	ax2.plot(x,yFixCCM,color="red",linestyle="dashed",linewidth=myLinewidth,label="Skal. (ii)")
	ax2.plot(invN1,e0Min1,marker="o",markersize=myMarkersizeBig,color="cyan",linestyle="None",label="Min.")
	ax2.plot(x,yQMC,color="cyan",linestyle="solid",linewidth=myLinewidth,label="Skal. (i)")
	ax2.plot(x,yCCM,color="cyan",linestyle="dashed",linewidth=myLinewidth,label="Skal. (ii)")
	ax2.set_xlabel(r"$1/l$")
	ax2.set_ylabel("$e_0/J$")
	lgd=ax2.legend(loc=ax2LegLoc,ncol=1,fontsize=myFontsize,fancybox=True)
	lgd.get_frame().set_linewidth(myLinewidth)

	ax3.plot(invN1mag,np.array(mag0Fix)/2,marker="s",markersize=myMarkersizeBig,color="red",linestyle="None",label="Fix.")
	ax3.plot(x,yMagFixQMC,color="red",linestyle="solid",linewidth=myLinewidth,label="Skal. (i)")
	ax3.plot(x,yMagFixCCM,color="red",linestyle="dashed",linewidth=myLinewidth,label="Skal. (ii)")
	ax3.plot(invN1mag,np.array(mag0Min1)/2,marker="o",markersize=myMarkersizeBig,color="cyan",linestyle="None",label="Min.")
	ax3.plot(x,yMagQMC,color="cyan",linestyle="solid",linewidth=myLinewidth,label="Skal. (i)")
	ax3.plot(x,yMagCCM,color="cyan",linestyle="dashed",linewidth=myLinewidth,label="Skal. (ii)")
	ax3.set_xlabel("$1/l$")
	ax3.set_ylabel("$m_0$")
	lgd=ax3.legend(loc=ax3LegLoc,ncol=1,fontsize=myFontsize,fancybox=True)
	lgd.get_frame().set_linewidth(myLinewidth)
	
	ax2.text(myTextOffset/2*0.5,ax2.get_ylim()[1],"(a)",fontsize=10)
	ax3.text(myTextOffset/2*0.5,ax3.get_ylim()[1],"(b)",fontsize=10)
	
	plt.savefig("NLCE_triangularOneHalf_XXZ_lambda{0}_gse_mag_scaling_da.pdf".format(lambdaValue))
	plt.clf();

	index=index+1



#plot complete lambda-axis
f, (ax1, ax2) = plt.subplots(2, sharex=False, sharey=False,figsize=(myFigsize_x, myFigsize_y)) #share x- and y-axis

ax1.plot(lambdaValueList,e0ScaledQMCList,marker="s",markersize=myMarkersizeBig,color="cyan",linestyle="None",label="Min. Skal. (i)",zorder=2)
ax1.plot(lambdaValueList,e0ScaledQMCList,marker="^",markersize=myMarkersizeBig,color="cyan",linestyle="None",label="Min. Skal. (ii)",zorder=4)
ax1.plot(lambdaValueList,e0FixScaledQMCList,marker="s",markersize=myMarkersizeBig,color="red",linestyle="None",label="Fix. Skal. (i)",zorder=3)
ax1.plot(lambdaValueList,e0FixScaledQMCList,marker="^",markersize=myMarkersizeBig,color="red",linestyle="None",label="Fix. Skal. (ii)",zorder=5)
x=np.arange(0,1.001,0.01)
e0Series=-0.375-0.16875*x**2+0.03375*x**3-0.04433705357*x**4+0.020425863*x**5-0.02832908602*x**6+0.03153484699*x**7-0.04765982794*x**8+0.06850871690*x**9-0.1025445984*x**10+0.1565521577*x**11-0.2455267547*x**12+0.3935047914*x**13
ax1.plot(x,e0Series,color="black",label="SE Ord. $13$",zorder=1)
ax1.plot([1],[-0.5458],marker="d",markersize=myMarkersizeBig,color="black",linestyle="None",clip_on=False,label="GFQMC",zorder=10)
ax1.plot([1],[-0.5502],marker="*",markersize=myMarkersizeBig,color="black",linestyle="None",clip_on=False,label="SE (extrapol.)",zorder=10)
ax1.set_xlabel("$\lambda$")
ax1.set_ylabel("$e_0/J$")
ax1.set_ylim([-0.6,-0.35])
ax1.text(myTextOffset/2,-0.35,"(a)",fontsize=10)
lgd=ax1.legend(loc="lower left",ncol=1,fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)

ax2.plot(lambdaValueList,m0BareList/2,marker="o",markersize=myMarkersizeBig,color="blue",linestyle="None",label="Min. Ord. $5$",zorder=3) #bare order 5 results
ax2.plot(lambdaValueList,mag0ScaledQMCList,marker="s",markersize=myMarkersizeBig,color="cyan",linestyle="None",label="Min. Skal. (i)",zorder=2)
ax2.plot(lambdaValueList,mag0ScaledCCMList,marker="^",markersize=myMarkersizeBig,color="cyan",linestyle="None",label="Min. Skal. (ii)",zorder=4)
ax2.plot(lambdaValueList,mag0FixScaledQMCList,marker="s",markersize=myMarkersizeBig,color="red",linestyle="None",label="Fix. Skal. (i)",zorder=3)
ax2.plot(lambdaValueList,mag0FixScaledCCMList,marker="^",markersize=myMarkersizeBig,color="red",linestyle="None",label="Fix. Skal. (ii)",zorder=5)
x=np.arange(0,1.001,0.01)
mag0Series=0.5-0.135*x**2+0.054*x**3-0.1363457908*x**4+0.08589755026*x**5-0.1657631567*x**6+0.2055368406*x**7-0.3691101414*x**8+0.5890651357*x**9-1.005494430*x**10+1.700641966*x**11-2.948749946*x**12+5.156611906*x**13
ax2.plot(x,mag0Series,color="black",label="SE Ord. $13$",zorder=1)
ax2.plot([1],[0.205],marker="d",markersize=myMarkersizeBig,color="black",linestyle="None",clip_on=False,label="GFQMC",zorder=10)
ax2.plot([1],[0.19],marker="*",markersize=myMarkersizeBig,color="black",linestyle="None",clip_on=False,label="SE (extrapol.)",zorder=10)
ax2.set_xlabel("$\lambda$")
ax2.set_ylabel("$m_0$")
ax2.set_ylim([0,0.52])
ax2.text(myTextOffset/2,0.5,"(b)",fontsize=10)
lgd=ax2.legend(loc="lower left",ncol=1,fontsize=myFontsize,fancybox=True)
lgd.get_frame().set_linewidth(myLinewidth)

plt.savefig("NLCE_triangularOneHalf_XXZ_da.pdf")
plt.clf()
