import numpy as np
import scipy as sp
from scipy.optimize import curve_fit

print(sp.__version__)

def m0QMCFit(x,a,b,c):
	return a*x**2+b*x+c

def m0CCMFit(x,a,b,c):
	return a*x**4+b*x**2+c

# create all files
f=open("minQMCFit.txt","w")
f.write("#lambda m2*x^2 + m1*x + m0\n")
f.close()

f=open("minCCMFit.txt","w")
f.write("#lambda m2*x^4 + m1*x^2 + m0\n")
f.close()

f=open("fixQMCFit.txt","w")
f.write("#lambda m2*x^2 + m1*x + m0\n")
f.close()

f=open("fixCCMFit.txt","w")
f.write("#lambda m2*x^4 + m1*x^2 + m0\n")
f.close()


# set bounds
minBound=[-np.inf,0,-np.inf]
maxBound=[np.inf,np.inf,np.inf]

# iterate over all lambda
lambdaValueList=[0.2,0.4,0.6,0.8,0.85,0.9,0.95,1]

for lambdaValue in lambdaValueList:
	print("\nlambda={0}".format(lambdaValue))
	# load minimum data
	mag0Min=np.loadtxt("lambda{0}_minimum.txt".format(lambdaValue),unpack=True)
	x=1/np.array(mag0Min[0][1:])
	y=np.array(mag0Min[1][1:])/2

	### m0 fit QMC minimum ###
	y2=y**2
	popt,pcov=curve_fit(m0QMCFit,x,y2,bounds=(minBound,maxBound))
	print("QMC_minimum={0}".format(popt))
	f=open("minQMCFit.txt","a")
	f.write("{3} {0} {1} {2}\n".format(popt[0],popt[1],popt[2],lambdaValue))
	f.close()

	### m0 fit CCM minimum ###
	popt,pcov=curve_fit(m0CCMFit,x,y,bounds=(minBound,maxBound))
	print("CCM_minimum={0}".format(popt))
	f=open("minCCMFit.txt","a")
	f.write("{3} {0} {1} {2}\n".format(popt[0],popt[1],popt[2],lambdaValue))
	f.close()

	# load fixpoint data
	mag0Fix=np.loadtxt("lambda{0}_fixpoint.txt".format(lambdaValue),unpack=True)
	x=1/np.array(mag0Fix[0][1:])
	y=np.array(mag0Fix[1][1:])/2

	### m0 fit QMC fixpoint ###
	y2=y**2
	popt,pcov=curve_fit(m0QMCFit,x,y2,bounds=(minBound,maxBound))
	print("QMC_fixpoint={0}".format(popt))
	f=open("fixQMCFit.txt","a")
	f.write("{3} {0} {1} {2}\n".format(popt[0],popt[1],popt[2],lambdaValue))
	f.close()

	### m0 fit CCM fixpoint ###
	popt,pcov=curve_fit(m0CCMFit,x,y,bounds=(minBound,maxBound))
	print("CCM_fixpoint={0}".format(popt))
	f=open("fixCCMFit.txt","a")
	f.write("{3} {0} {1} {2}\n".format(popt[0],popt[1],popt[2],lambdaValue))
	f.close()

